from ........Internal.Core import Core
from ........Internal.CommandsGroup import CommandsGroup


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Sdynamics:
	"""Sdynamics commands group definition. 12 total commands, 12 Sub-groups, 0 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._base = CommandsGroup("sdynamics", core, parent)

	@property
	def accel(self):
		"""accel commands group. 1 Sub-classes, 0 commands."""
		if not hasattr(self, '_accel'):
			from .Accel import Accel
			self._accel = Accel(self._core, self._base)
		return self._accel

	@property
	def caPeriod(self):
		"""caPeriod commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_caPeriod'):
			from .CaPeriod import CaPeriod
			self._caPeriod = CaPeriod(self._core, self._base)
		return self._caPeriod

	@property
	def config(self):
		"""config commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_config'):
			from .Config import Config
			self._config = Config(self._core, self._base)
		return self._config

	@property
	def cphase(self):
		"""cphase commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_cphase'):
			from .Cphase import Cphase
			self._cphase = Cphase(self._core, self._base)
		return self._cphase

	@property
	def cvPeriod(self):
		"""cvPeriod commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_cvPeriod'):
			from .CvPeriod import CvPeriod
			self._cvPeriod = CvPeriod(self._core, self._base)
		return self._cvPeriod

	@property
	def ivelocity(self):
		"""ivelocity commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_ivelocity'):
			from .Ivelocity import Ivelocity
			self._ivelocity = Ivelocity(self._core, self._base)
		return self._ivelocity

	@property
	def jerk(self):
		"""jerk commands group. 1 Sub-classes, 0 commands."""
		if not hasattr(self, '_jerk'):
			from .Jerk import Jerk
			self._jerk = Jerk(self._core, self._base)
		return self._jerk

	@property
	def prange(self):
		"""prange commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_prange'):
			from .Prange import Prange
			self._prange = Prange(self._core, self._base)
		return self._prange

	@property
	def profile(self):
		"""profile commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_profile'):
			from .Profile import Profile
			self._profile = Profile(self._core, self._base)
		return self._profile

	@property
	def rperiod(self):
		"""rperiod commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_rperiod'):
			from .Rperiod import Rperiod
			self._rperiod = Rperiod(self._core, self._base)
		return self._rperiod

	@property
	def toffset(self):
		"""toffset commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_toffset'):
			from .Toffset import Toffset
			self._toffset = Toffset(self._core, self._base)
		return self._toffset

	@property
	def velocity(self):
		"""velocity commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_velocity'):
			from .Velocity import Velocity
			self._velocity = Velocity(self._core, self._base)
		return self._velocity

	def clone(self) -> 'Sdynamics':
		"""Clones the group by creating new object from it and its whole existing sub-groups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = Sdynamics(self._core, self._base.parent)
		self._base.synchronize_repcaps(new_group)
		return new_group



from ....Internal.Core import Core
from ....Internal.CommandsGroup import CommandsGroup
from ....Internal import Conversions
from ....Internal.Utilities import trim_str_response
from .... import enums


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Serial:
	"""Serial commands group definition. 4 total commands, 0 Sub-groups, 4 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._base = CommandsGroup("serial", core, parent)

	# noinspection PyTypeChecker
	def get_baud(self) -> enums.Rs232BdRate:
		"""SCPI: SYSTem:COMMunicate:SERial:BAUD \n
		Snippet: value: enums.Rs232BdRate = driver.system.communicate.serial.get_baud() \n
		Defines the baudrate for the serial remote control interface. \n
			:return: baud: 2400| 4800| 9600| 19200| 38400| 57600| 115200
		"""
		response = self._core.io.query_str('SYSTem:COMMunicate:SERial:BAUD?')
		return Conversions.str_to_scalar_enum(response, enums.Rs232BdRate)

	def set_baud(self, baud: enums.Rs232BdRate) -> None:
		"""SCPI: SYSTem:COMMunicate:SERial:BAUD \n
		Snippet: driver.system.communicate.serial.set_baud(baud = enums.Rs232BdRate._115200) \n
		Defines the baudrate for the serial remote control interface. \n
			:param baud: 2400| 4800| 9600| 19200| 38400| 57600| 115200
		"""
		param = Conversions.enum_scalar_to_str(baud, enums.Rs232BdRate)
		self._core.io.write(f'SYSTem:COMMunicate:SERial:BAUD {param}')

	# noinspection PyTypeChecker
	def get_parity(self) -> enums.Parity:
		"""SCPI: SYSTem:COMMunicate:SERial:PARity \n
		Snippet: value: enums.Parity = driver.system.communicate.serial.get_parity() \n
		Enters the parity for the serial remote control interface. \n
			:return: parity: NONE| ODD| EVEN
		"""
		response = self._core.io.query_str('SYSTem:COMMunicate:SERial:PARity?')
		return Conversions.str_to_scalar_enum(response, enums.Parity)

	def set_parity(self, parity: enums.Parity) -> None:
		"""SCPI: SYSTem:COMMunicate:SERial:PARity \n
		Snippet: driver.system.communicate.serial.set_parity(parity = enums.Parity.EVEN) \n
		Enters the parity for the serial remote control interface. \n
			:param parity: NONE| ODD| EVEN
		"""
		param = Conversions.enum_scalar_to_str(parity, enums.Parity)
		self._core.io.write(f'SYSTem:COMMunicate:SERial:PARity {param}')

	def get_resource(self) -> str:
		"""SCPI: SYSTem:COMMunicate:SERial:RESource \n
		Snippet: value: str = driver.system.communicate.serial.get_resource() \n
		Queries the visa resource string for the serial remote control interface. This string is used for remote control of the
		instrument. \n
			:return: resource: string
		"""
		response = self._core.io.query_str('SYSTem:COMMunicate:SERial:RESource?')
		return trim_str_response(response)

	# noinspection PyTypeChecker
	def get_sbits(self) -> enums.Count:
		"""SCPI: SYSTem:COMMunicate:SERial:SBITs \n
		Snippet: value: enums.Count = driver.system.communicate.serial.get_sbits() \n
		Defines the number of stop bits for the serial remote control interface. \n
			:return: sbits: 1| 2
		"""
		response = self._core.io.query_str('SYSTem:COMMunicate:SERial:SBITs?')
		return Conversions.str_to_scalar_enum(response, enums.Count)

	def set_sbits(self, sbits: enums.Count) -> None:
		"""SCPI: SYSTem:COMMunicate:SERial:SBITs \n
		Snippet: driver.system.communicate.serial.set_sbits(sbits = enums.Count._1) \n
		Defines the number of stop bits for the serial remote control interface. \n
			:param sbits: 1| 2
		"""
		param = Conversions.enum_scalar_to_str(sbits, enums.Count)
		self._core.io.write(f'SYSTem:COMMunicate:SERial:SBITs {param}')



from ........Internal.Core import Core
from ........Internal.CommandsGroup import CommandsGroup


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Tmph:
	"""Tmph commands group definition. 5 total commands, 5 Sub-groups, 0 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._base = CommandsGroup("tmph", core, parent)

	@property
	def ctOffset(self):
		"""ctOffset commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_ctOffset'):
			from .CtOffset import CtOffset
			self._ctOffset = CtOffset(self._core, self._base)
		return self._ctOffset

	@property
	def phOffset(self):
		"""phOffset commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_phOffset'):
			from .PhOffset import PhOffset
			self._phOffset = PhOffset(self._core, self._base)
		return self._phOffset

	@property
	def sfOffset(self):
		"""sfOffset commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_sfOffset'):
			from .SfOffset import SfOffset
			self._sfOffset = SfOffset(self._core, self._base)
		return self._sfOffset

	@property
	def syfnOffset(self):
		"""syfnOffset commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_syfnOffset'):
			from .SyfnOffset import SyfnOffset
			self._syfnOffset = SyfnOffset(self._core, self._base)
		return self._syfnOffset

	@property
	def taOffset(self):
		"""taOffset commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_taOffset'):
			from .TaOffset import TaOffset
			self._taOffset = TaOffset(self._core, self._base)
		return self._taOffset

	def clone(self) -> 'Tmph':
		"""Clones the group by creating new object from it and its whole existing sub-groups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = Tmph(self._core, self._base.parent)
		self._base.synchronize_repcaps(new_group)
		return new_group



from .......Internal.Core import Core
from .......Internal.CommandsGroup import CommandsGroup
from .......Internal import Conversions


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class External:
	"""External commands group definition. 5 total commands, 1 Sub-groups, 4 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._base = CommandsGroup("external", core, parent)

	@property
	def synchronize(self):
		"""synchronize commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_synchronize'):
			from .Synchronize import Synchronize
			self._synchronize = Synchronize(self._core, self._base)
		return self._synchronize

	def get_rdelay(self) -> float:
		"""SCPI: [SOURce<HW>]:BB:ONEWeb:TRIGger:EXTernal:RDELay \n
		Snippet: value: float = driver.source.bb.oneweb.trigger.external.get_rdelay() \n
		Queries the time (in seconds) an external trigger event is delayed for. \n
			:return: trig_ext_time_res_d: float Range: 0 to 688
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:BB:ONEWeb:TRIGger:EXTernal:RDELay?')
		return Conversions.str_to_float(response)

	def get_tdelay(self) -> float:
		"""SCPI: [SOURce<HW>]:BB:ONEWeb:TRIGger:EXTernal:TDELay \n
		Snippet: value: float = driver.source.bb.oneweb.trigger.external.get_tdelay() \n
		Specifies the trigger delay for external triggering. The value affects all external trigger signals. \n
			:return: trig_ext_time_del: float Range: 0 to 688
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:BB:ONEWeb:TRIGger:EXTernal:TDELay?')
		return Conversions.str_to_float(response)

	def set_tdelay(self, trig_ext_time_del: float) -> None:
		"""SCPI: [SOURce<HW>]:BB:ONEWeb:TRIGger:EXTernal:TDELay \n
		Snippet: driver.source.bb.oneweb.trigger.external.set_tdelay(trig_ext_time_del = 1.0) \n
		Specifies the trigger delay for external triggering. The value affects all external trigger signals. \n
			:param trig_ext_time_del: float Range: 0 to 688
		"""
		param = Conversions.decimal_value_to_str(trig_ext_time_del)
		self._core.io.write(f'SOURce<HwInstance>:BB:ONEWeb:TRIGger:EXTernal:TDELay {param}')

	def get_delay(self) -> float:
		"""SCPI: [SOURce<HW>]:BB:ONEWeb:TRIGger:[EXTernal]:DELay \n
		Snippet: value: float = driver.source.bb.oneweb.trigger.external.get_delay() \n
		Sets the trigger delay. \n
			:return: trig_ext_delay: float Range: 0 to 68719476735
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:BB:ONEWeb:TRIGger:EXTernal:DELay?')
		return Conversions.str_to_float(response)

	def set_delay(self, trig_ext_delay: float) -> None:
		"""SCPI: [SOURce<HW>]:BB:ONEWeb:TRIGger:[EXTernal]:DELay \n
		Snippet: driver.source.bb.oneweb.trigger.external.set_delay(trig_ext_delay = 1.0) \n
		Sets the trigger delay. \n
			:param trig_ext_delay: float Range: 0 to 68719476735
		"""
		param = Conversions.decimal_value_to_str(trig_ext_delay)
		self._core.io.write(f'SOURce<HwInstance>:BB:ONEWeb:TRIGger:EXTernal:DELay {param}')

	def get_inhibit(self) -> int:
		"""SCPI: [SOURce<HW>]:BB:ONEWeb:TRIGger:[EXTernal]:INHibit \n
		Snippet: value: int = driver.source.bb.oneweb.trigger.external.get_inhibit() \n
		Specifies the duration by which a restart is inhibited. \n
			:return: trig_ext_inhibit: integer Range: 0 to 67108863
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:BB:ONEWeb:TRIGger:EXTernal:INHibit?')
		return Conversions.str_to_int(response)

	def set_inhibit(self, trig_ext_inhibit: int) -> None:
		"""SCPI: [SOURce<HW>]:BB:ONEWeb:TRIGger:[EXTernal]:INHibit \n
		Snippet: driver.source.bb.oneweb.trigger.external.set_inhibit(trig_ext_inhibit = 1) \n
		Specifies the duration by which a restart is inhibited. \n
			:param trig_ext_inhibit: integer Range: 0 to 67108863
		"""
		param = Conversions.decimal_value_to_str(trig_ext_inhibit)
		self._core.io.write(f'SOURce<HwInstance>:BB:ONEWeb:TRIGger:EXTernal:INHibit {param}')

	def clone(self) -> 'External':
		"""Clones the group by creating new object from it and its whole existing sub-groups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = External(self._core, self._base.parent)
		self._base.synchronize_repcaps(new_group)
		return new_group



from .......Internal.Core import Core
from .......Internal.CommandsGroup import CommandsGroup
from .......Internal import Conversions
from ....... import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Nsubframe:
	"""Nsubframe commands group definition. 1 total commands, 0 Sub-groups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._base = CommandsGroup("nsubframe", core, parent)

	def set(self, num_sched_subframe: int, cellNull=repcap.CellNull.Default) -> None:
		"""SCPI: [SOURce<HW>]:BB:NR5G:SCHed:CELL<CH0>:NSUBframe \n
		Snippet: driver.source.bb.nr5G.scheduling.cell.nsubframe.set(num_sched_subframe = 1, cellNull = repcap.CellNull.Default) \n
		No command help available \n
			:param num_sched_subframe: No help available
			:param cellNull: optional repeated capability selector. Default value: Nr0 (settable in the interface 'Cell')"""
		param = Conversions.decimal_value_to_str(num_sched_subframe)
		cellNull_cmd_val = self._base.get_repcap_cmd_value(cellNull, repcap.CellNull)
		self._core.io.write(f'SOURce<HwInstance>:BB:NR5G:SCHed:CELL{cellNull_cmd_val}:NSUBframe {param}')

	def get(self, cellNull=repcap.CellNull.Default) -> int:
		"""SCPI: [SOURce<HW>]:BB:NR5G:SCHed:CELL<CH0>:NSUBframe \n
		Snippet: value: int = driver.source.bb.nr5G.scheduling.cell.nsubframe.get(cellNull = repcap.CellNull.Default) \n
		No command help available \n
			:param cellNull: optional repeated capability selector. Default value: Nr0 (settable in the interface 'Cell')
			:return: num_sched_subframe: No help available"""
		cellNull_cmd_val = self._base.get_repcap_cmd_value(cellNull, repcap.CellNull)
		response = self._core.io.query_str(f'SOURce<HwInstance>:BB:NR5G:SCHed:CELL{cellNull_cmd_val}:NSUBframe?')
		return Conversions.str_to_int(response)



from .......Internal.Core import Core
from .......Internal.CommandsGroup import CommandsGroup
from .......Internal import Conversions
from ....... import enums


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Rows:
	"""Rows commands group definition. 1 total commands, 0 Sub-groups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._base = CommandsGroup("rows", core, parent)

	# noinspection PyTypeChecker
	def get_size(self) -> enums.SystConfFadEntOutp:
		"""SCPI: [SOURce<HW>]:FSIMulator:SCM:ANTenna:TX:ROWS:[SIZE] \n
		Snippet: value: enums.SystConfFadEntOutp = driver.source.fsimulator.scm.antenna.tx.rows.get_size() \n
		Queries the number of rows and the number of columns in the antenna array. \n
			:return: num_tx_rows: R01| R02| R03| R04| R08
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:FSIMulator:SCM:ANTenna:TX:ROWS:SIZE?')
		return Conversions.str_to_scalar_enum(response, enums.SystConfFadEntOutp)



from .........Internal.Core import Core
from .........Internal.CommandsGroup import CommandsGroup
from .........Internal import Conversions
from .........Internal.RepeatedCapability import RepeatedCapability
from ......... import enums
from ......... import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Modulation:
	"""Modulation commands group definition. 1 total commands, 0 Sub-groups, 1 group commands
	Repeated Capability: TwoStreams, default value after init: TwoStreams.Nr1"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._base = CommandsGroup("modulation", core, parent)
		self._base.rep_cap = RepeatedCapability(self._base.group_name, 'repcap_twoStreams_get', 'repcap_twoStreams_set', repcap.TwoStreams.Nr1)

	def repcap_twoStreams_set(self, enum_value: repcap.TwoStreams) -> None:
		"""Repeated Capability default value numeric suffix.
		This value is used, if you do not explicitely set it in the child set/get methods, or if you leave it to TwoStreams.Default
		Default value after init: TwoStreams.Nr1"""
		self._base.set_repcap_enum_value(enum_value)

	def repcap_twoStreams_get(self) -> repcap.TwoStreams:
		"""Returns the current default repeated capability for the child set/get methods"""
		# noinspection PyTypeChecker
		return self._base.get_repcap_enum_value()

	def set(self, modulation: enums.ModulationC, baseStation=repcap.BaseStation.Default, channelNull=repcap.ChannelNull.Default, twoStreams=repcap.TwoStreams.Default) -> None:
		"""SCPI: [SOURce<HW>]:BB:W3GPp:BSTation<ST>:CHANnel<CH0>:HSDPa:HSET:MODulation<DI> \n
		Snippet: driver.source.bb.w3Gpp.bstation.channel.hsdpa.hset.modulation.set(modulation = enums.ModulationC.QAM16, baseStation = repcap.BaseStation.Default, channelNull = repcap.ChannelNull.Default, twoStreams = repcap.TwoStreams.Default) \n
		Sets the modulation for stream 1 and stream 2 to QPSK, 16QAM or 64QAM. For HS-SCCH Type 2, the available modulation
		scheme is QPSK only. \n
			:param modulation: QPSK| QAM16| QAM64
			:param baseStation: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Bstation')
			:param channelNull: optional repeated capability selector. Default value: Nr0 (settable in the interface 'Channel')
			:param twoStreams: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Modulation')"""
		param = Conversions.enum_scalar_to_str(modulation, enums.ModulationC)
		baseStation_cmd_val = self._base.get_repcap_cmd_value(baseStation, repcap.BaseStation)
		channelNull_cmd_val = self._base.get_repcap_cmd_value(channelNull, repcap.ChannelNull)
		twoStreams_cmd_val = self._base.get_repcap_cmd_value(twoStreams, repcap.TwoStreams)
		self._core.io.write(f'SOURce<HwInstance>:BB:W3GPp:BSTation{baseStation_cmd_val}:CHANnel{channelNull_cmd_val}:HSDPa:HSET:MODulation{twoStreams_cmd_val} {param}')

	# noinspection PyTypeChecker
	def get(self, baseStation=repcap.BaseStation.Default, channelNull=repcap.ChannelNull.Default, twoStreams=repcap.TwoStreams.Default) -> enums.ModulationC:
		"""SCPI: [SOURce<HW>]:BB:W3GPp:BSTation<ST>:CHANnel<CH0>:HSDPa:HSET:MODulation<DI> \n
		Snippet: value: enums.ModulationC = driver.source.bb.w3Gpp.bstation.channel.hsdpa.hset.modulation.get(baseStation = repcap.BaseStation.Default, channelNull = repcap.ChannelNull.Default, twoStreams = repcap.TwoStreams.Default) \n
		Sets the modulation for stream 1 and stream 2 to QPSK, 16QAM or 64QAM. For HS-SCCH Type 2, the available modulation
		scheme is QPSK only. \n
			:param baseStation: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Bstation')
			:param channelNull: optional repeated capability selector. Default value: Nr0 (settable in the interface 'Channel')
			:param twoStreams: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Modulation')
			:return: modulation: QPSK| QAM16| QAM64"""
		baseStation_cmd_val = self._base.get_repcap_cmd_value(baseStation, repcap.BaseStation)
		channelNull_cmd_val = self._base.get_repcap_cmd_value(channelNull, repcap.ChannelNull)
		twoStreams_cmd_val = self._base.get_repcap_cmd_value(twoStreams, repcap.TwoStreams)
		response = self._core.io.query_str(f'SOURce<HwInstance>:BB:W3GPp:BSTation{baseStation_cmd_val}:CHANnel{channelNull_cmd_val}:HSDPa:HSET:MODulation{twoStreams_cmd_val}?')
		return Conversions.str_to_scalar_enum(response, enums.ModulationC)

	def clone(self) -> 'Modulation':
		"""Clones the group by creating new object from it and its whole existing sub-groups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = Modulation(self._core, self._base.parent)
		self._base.synchronize_repcaps(new_group)
		return new_group



from ........Internal.Core import Core
from ........Internal.CommandsGroup import CommandsGroup
from ........Internal import Conversions
from ........ import enums
from ........ import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class ConType:
	"""ConType commands group definition. 1 total commands, 0 Sub-groups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._base = CommandsGroup("conType", core, parent)

	def set(self, content_type: enums.EutraUlContentTypeWithIot, subframeNull=repcap.SubframeNull.Default, allocationNull=repcap.AllocationNull.Default) -> None:
		"""SCPI: [SOURce<HW>]:BB:EUTRa:UL:[SUBF<ST0>]:ALLoc<CH0>:CONType \n
		Snippet: driver.source.bb.eutra.uplink.subf.alloc.conType.set(content_type = enums.EutraUlContentTypeWithIot.EMTC, subframeNull = repcap.SubframeNull.Default, allocationNull = repcap.AllocationNull.Default) \n
		Selects the content type for the selected allocation. \n
			:param content_type: PUSCh| PUCCh | EMTC| NIOT
			:param subframeNull: optional repeated capability selector. Default value: Nr0 (settable in the interface 'Subf')
			:param allocationNull: optional repeated capability selector. Default value: Nr0 (settable in the interface 'Alloc')"""
		param = Conversions.enum_scalar_to_str(content_type, enums.EutraUlContentTypeWithIot)
		subframeNull_cmd_val = self._base.get_repcap_cmd_value(subframeNull, repcap.SubframeNull)
		allocationNull_cmd_val = self._base.get_repcap_cmd_value(allocationNull, repcap.AllocationNull)
		self._core.io.write(f'SOURce<HwInstance>:BB:EUTRa:UL:SUBF{subframeNull_cmd_val}:ALLoc{allocationNull_cmd_val}:CONType {param}')

	# noinspection PyTypeChecker
	def get(self, subframeNull=repcap.SubframeNull.Default, allocationNull=repcap.AllocationNull.Default) -> enums.EutraUlContentTypeWithIot:
		"""SCPI: [SOURce<HW>]:BB:EUTRa:UL:[SUBF<ST0>]:ALLoc<CH0>:CONType \n
		Snippet: value: enums.EutraUlContentTypeWithIot = driver.source.bb.eutra.uplink.subf.alloc.conType.get(subframeNull = repcap.SubframeNull.Default, allocationNull = repcap.AllocationNull.Default) \n
		Selects the content type for the selected allocation. \n
			:param subframeNull: optional repeated capability selector. Default value: Nr0 (settable in the interface 'Subf')
			:param allocationNull: optional repeated capability selector. Default value: Nr0 (settable in the interface 'Alloc')
			:return: content_type: PUSCh| PUCCh | EMTC| NIOT"""
		subframeNull_cmd_val = self._base.get_repcap_cmd_value(subframeNull, repcap.SubframeNull)
		allocationNull_cmd_val = self._base.get_repcap_cmd_value(allocationNull, repcap.AllocationNull)
		response = self._core.io.query_str(f'SOURce<HwInstance>:BB:EUTRa:UL:SUBF{subframeNull_cmd_val}:ALLoc{allocationNull_cmd_val}:CONType?')
		return Conversions.str_to_scalar_enum(response, enums.EutraUlContentTypeWithIot)



from ..........Internal.Core import Core
from ..........Internal.CommandsGroup import CommandsGroup
from ..........Internal import Conversions
from ..........Internal.RepeatedCapability import RepeatedCapability
from .......... import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Sf:
	"""Sf commands group definition. 1 total commands, 0 Sub-groups, 1 group commands
	Repeated Capability: Region, default value after init: Region.Nr1"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._base = CommandsGroup("sf", core, parent)
		self._base.rep_cap = RepeatedCapability(self._base.group_name, 'repcap_region_get', 'repcap_region_set', repcap.Region.Nr1)

	def repcap_region_set(self, enum_value: repcap.Region) -> None:
		"""Repeated Capability default value numeric suffix.
		This value is used, if you do not explicitely set it in the child set/get methods, or if you leave it to Region.Default
		Default value after init: Region.Nr1"""
		self._base.set_repcap_enum_value(enum_value)

	def repcap_region_get(self) -> repcap.Region:
		"""Returns the current default repeated capability for the child set/get methods"""
		# noinspection PyTypeChecker
		return self._base.get_repcap_enum_value()

	def set(self, sf: int, region=repcap.Region.Default) -> None:
		"""SCPI: [SOURce<HW>]:BB:GNSS:ATMospheric:GALileo:[NMESsage]:[FNAV]:IONospheric:SF<CH> \n
		Snippet: driver.source.bb.gnss.atmospheric.galileo.nmessage.fnav.ionospheric.sf.set(sf = 1, region = repcap.Region.Default) \n
		Sets the parameters ionospheric disturbance flag for region 1 to 5 of the satellite's navigation message. \n
			:param sf: integer Range: 0 to 1
			:param region: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Sf')"""
		param = Conversions.decimal_value_to_str(sf)
		region_cmd_val = self._base.get_repcap_cmd_value(region, repcap.Region)
		self._core.io.write(f'SOURce<HwInstance>:BB:GNSS:ATMospheric:GALileo:NMESsage:FNAV:IONospheric:SF{region_cmd_val} {param}')

	def get(self, region=repcap.Region.Default) -> int:
		"""SCPI: [SOURce<HW>]:BB:GNSS:ATMospheric:GALileo:[NMESsage]:[FNAV]:IONospheric:SF<CH> \n
		Snippet: value: int = driver.source.bb.gnss.atmospheric.galileo.nmessage.fnav.ionospheric.sf.get(region = repcap.Region.Default) \n
		Sets the parameters ionospheric disturbance flag for region 1 to 5 of the satellite's navigation message. \n
			:param region: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Sf')
			:return: sf: integer Range: 0 to 1"""
		region_cmd_val = self._base.get_repcap_cmd_value(region, repcap.Region)
		response = self._core.io.query_str(f'SOURce<HwInstance>:BB:GNSS:ATMospheric:GALileo:NMESsage:FNAV:IONospheric:SF{region_cmd_val}?')
		return Conversions.str_to_int(response)

	def clone(self) -> 'Sf':
		"""Clones the group by creating new object from it and its whole existing sub-groups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = Sf(self._core, self._base.parent)
		self._base.synchronize_repcaps(new_group)
		return new_group



from typing import List

from ........Internal.Core import Core
from ........Internal.CommandsGroup import CommandsGroup
from ........Internal import Conversions
from ........ import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Sreserved:
	"""Sreserved commands group definition. 1 total commands, 0 Sub-groups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._base = CommandsGroup("sreserved", core, parent)

	def set(self, reserved: List[str], frameBlock=repcap.FrameBlock.Default) -> None:
		"""SCPI: [SOURce<HW>]:BB:WLNN:FBLock<CH>:MAC:HTControl:SREServed \n
		Snippet: driver.source.bb.wlnn.fblock.mac.htControl.sreserved.set(reserved = ['raw1', 'raw2', 'raw3'], frameBlock = repcap.FrameBlock.Default) \n
		This signal field is currently defined, but not used. \n
			:param reserved: integer
			:param frameBlock: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Fblock')"""
		param = Conversions.list_to_csv_str(reserved)
		frameBlock_cmd_val = self._base.get_repcap_cmd_value(frameBlock, repcap.FrameBlock)
		self._core.io.write(f'SOURce<HwInstance>:BB:WLNN:FBLock{frameBlock_cmd_val}:MAC:HTControl:SREServed {param}')

	def get(self, frameBlock=repcap.FrameBlock.Default) -> List[str]:
		"""SCPI: [SOURce<HW>]:BB:WLNN:FBLock<CH>:MAC:HTControl:SREServed \n
		Snippet: value: List[str] = driver.source.bb.wlnn.fblock.mac.htControl.sreserved.get(frameBlock = repcap.FrameBlock.Default) \n
		This signal field is currently defined, but not used. \n
			:param frameBlock: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Fblock')
			:return: reserved: integer"""
		frameBlock_cmd_val = self._base.get_repcap_cmd_value(frameBlock, repcap.FrameBlock)
		response = self._core.io.query_str(f'SOURce<HwInstance>:BB:WLNN:FBLock{frameBlock_cmd_val}:MAC:HTControl:SREServed?')
		return Conversions.str_to_str_list(response)



from ....Internal.Core import Core
from ....Internal.CommandsGroup import CommandsGroup
from ....Internal import Conversions
from .... import enums


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Frequency:
	"""Frequency commands group definition. 2 total commands, 0 Sub-groups, 2 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._base = CommandsGroup("frequency", core, parent)

	# noinspection PyTypeChecker
	def get_detect(self) -> enums.TmastConn:
		"""SCPI: [SOURce<HW>]:FSIMulator:FREQuency:DETect \n
		Snippet: value: enums.TmastConn = driver.source.fsimulator.frequency.get_detect() \n
		Queries the output interface the steam used to estimate the dedicated frequency is mapped to. \n
			:return: detect_primary: RFA| BBMM1| RFB| BBMM2| IQOUT1| IQOUT2| FAD1| FAD2| FAD4| FAD3| DEF
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:FSIMulator:FREQuency:DETect?')
		return Conversions.str_to_scalar_enum(response, enums.TmastConn)

	def get_value(self) -> float:
		"""SCPI: [SOURce<HW>]:FSIMulator:FREQuency \n
		Snippet: value: float = driver.source.fsimulator.frequency.get_value() \n
			INTRO_CMD_HELP: The effect depends on the selected mode: \n
			- If [:SOURce<hw>]:FSIMulator:SDEStinationRF is selected, queries the estimated RF frequency.
			- If [:SOURce<hw>]:FSIMulator:SDEStinationBB is selected, sets the frequency used for the calculation of the Doppler shift. \n
			:return: frequency: float Range: 1E5 to 100E9, Unit: Hz
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:FSIMulator:FREQuency?')
		return Conversions.str_to_float(response)

	def set_value(self, frequency: float) -> None:
		"""SCPI: [SOURce<HW>]:FSIMulator:FREQuency \n
		Snippet: driver.source.fsimulator.frequency.set_value(frequency = 1.0) \n
			INTRO_CMD_HELP: The effect depends on the selected mode: \n
			- If [:SOURce<hw>]:FSIMulator:SDEStinationRF is selected, queries the estimated RF frequency.
			- If [:SOURce<hw>]:FSIMulator:SDEStinationBB is selected, sets the frequency used for the calculation of the Doppler shift. \n
			:param frequency: float Range: 1E5 to 100E9, Unit: Hz
		"""
		param = Conversions.decimal_value_to_str(frequency)
		self._core.io.write(f'SOURce<HwInstance>:FSIMulator:FREQuency {param}')



from ........Internal.Core import Core
from ........Internal.CommandsGroup import CommandsGroup


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class ConSubFrames:
	"""ConSubFrames commands group definition. 2 total commands, 2 Sub-groups, 0 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._base = CommandsGroup("conSubFrames", core, parent)

	@property
	def xpucch(self):
		"""xpucch commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_xpucch'):
			from .Xpucch import Xpucch
			self._xpucch = Xpucch(self._core, self._base)
		return self._xpucch

	@property
	def xpusch(self):
		"""xpusch commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_xpusch'):
			from .Xpusch import Xpusch
			self._xpusch = Xpusch(self._core, self._base)
		return self._xpusch

	def clone(self) -> 'ConSubFrames':
		"""Clones the group by creating new object from it and its whole existing sub-groups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = ConSubFrames(self._core, self._base.parent)
		self._base.synchronize_repcaps(new_group)
		return new_group



from .....Internal.Core import Core
from .....Internal.CommandsGroup import CommandsGroup
from .....Internal import Conversions
from .....Internal.Utilities import trim_str_response
from ..... import enums


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Oneweb:
	"""Oneweb commands group definition. 654 total commands, 16 Sub-groups, 7 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._base = CommandsGroup("oneweb", core, parent)

	@property
	def clipping(self):
		"""clipping commands group. 0 Sub-classes, 3 commands."""
		if not hasattr(self, '_clipping'):
			from .Clipping import Clipping
			self._clipping = Clipping(self._core, self._base)
		return self._clipping

	@property
	def clock(self):
		"""clock commands group. 0 Sub-classes, 4 commands."""
		if not hasattr(self, '_clock'):
			from .Clock import Clock
			self._clock = Clock(self._core, self._base)
		return self._clock

	@property
	def downlink(self):
		"""downlink commands group. 19 Sub-classes, 15 commands."""
		if not hasattr(self, '_downlink'):
			from .Downlink import Downlink
			self._downlink = Downlink(self._core, self._base)
		return self._downlink

	@property
	def filterPy(self):
		"""filterPy commands group. 1 Sub-classes, 3 commands."""
		if not hasattr(self, '_filterPy'):
			from .FilterPy import FilterPy
			self._filterPy = FilterPy(self._core, self._base)
		return self._filterPy

	@property
	def notch(self):
		"""notch commands group. 4 Sub-classes, 3 commands."""
		if not hasattr(self, '_notch'):
			from .Notch import Notch
			self._notch = Notch(self._core, self._base)
		return self._notch

	@property
	def powc(self):
		"""powc commands group. 0 Sub-classes, 4 commands."""
		if not hasattr(self, '_powc'):
			from .Powc import Powc
			self._powc = Powc(self._core, self._base)
		return self._powc

	@property
	def refSignal(self):
		"""refSignal commands group. 0 Sub-classes, 2 commands."""
		if not hasattr(self, '_refSignal'):
			from .RefSignal import RefSignal
			self._refSignal = RefSignal(self._core, self._base)
		return self._refSignal

	@property
	def setting(self):
		"""setting commands group. 1 Sub-classes, 4 commands."""
		if not hasattr(self, '_setting'):
			from .Setting import Setting
			self._setting = Setting(self._core, self._base)
		return self._setting

	@property
	def symbolRate(self):
		"""symbolRate commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_symbolRate'):
			from .SymbolRate import SymbolRate
			self._symbolRate = SymbolRate(self._core, self._base)
		return self._symbolRate

	@property
	def tdd(self):
		"""tdd commands group. 0 Sub-classes, 2 commands."""
		if not hasattr(self, '_tdd'):
			from .Tdd import Tdd
			self._tdd = Tdd(self._core, self._base)
		return self._tdd

	@property
	def tdw(self):
		"""tdw commands group. 0 Sub-classes, 2 commands."""
		if not hasattr(self, '_tdw'):
			from .Tdw import Tdw
			self._tdw = Tdw(self._core, self._base)
		return self._tdw

	@property
	def timc(self):
		"""timc commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_timc'):
			from .Timc import Timc
			self._timc = Timc(self._core, self._base)
		return self._timc

	@property
	def trigger(self):
		"""trigger commands group. 6 Sub-classes, 5 commands."""
		if not hasattr(self, '_trigger'):
			from .Trigger import Trigger
			self._trigger = Trigger(self._core, self._base)
		return self._trigger

	@property
	def udt(self):
		"""udt commands group. 0 Sub-classes, 3 commands."""
		if not hasattr(self, '_udt'):
			from .Udt import Udt
			self._udt = Udt(self._core, self._base)
		return self._udt

	@property
	def uplink(self):
		"""uplink commands group. 11 Sub-classes, 13 commands."""
		if not hasattr(self, '_uplink'):
			from .Uplink import Uplink
			self._uplink = Uplink(self._core, self._base)
		return self._uplink

	@property
	def waveform(self):
		"""waveform commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_waveform'):
			from .Waveform import Waveform
			self._waveform = Waveform(self._core, self._base)
		return self._waveform

	# noinspection PyTypeChecker
	def get_cmod(self) -> enums.OneWebConfMode:
		"""SCPI: [SOURce<HW>]:BB:ONEWeb:CMOD \n
		Snippet: value: enums.OneWebConfMode = driver.source.bb.oneweb.get_cmod() \n
		Sets the configuration mode. \n
			:return: config_mode: PREDefined| USER
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:BB:ONEWeb:CMOD?')
		return Conversions.str_to_scalar_enum(response, enums.OneWebConfMode)

	def set_cmod(self, config_mode: enums.OneWebConfMode) -> None:
		"""SCPI: [SOURce<HW>]:BB:ONEWeb:CMOD \n
		Snippet: driver.source.bb.oneweb.set_cmod(config_mode = enums.OneWebConfMode.PREDefined) \n
		Sets the configuration mode. \n
			:param config_mode: PREDefined| USER
		"""
		param = Conversions.enum_scalar_to_str(config_mode, enums.OneWebConfMode)
		self._core.io.write(f'SOURce<HwInstance>:BB:ONEWeb:CMOD {param}')

	# noinspection PyTypeChecker
	def get_duplexing(self) -> enums.OneWebDuplexModeRange:
		"""SCPI: [SOURce<HW>]:BB:ONEWeb:DUPLexing \n
		Snippet: value: enums.OneWebDuplexModeRange = driver.source.bb.oneweb.get_duplexing() \n
		Queries the duplexing mode. \n
			:return: duplexing: FDD
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:BB:ONEWeb:DUPLexing?')
		return Conversions.str_to_scalar_enum(response, enums.OneWebDuplexModeRange)

	# noinspection PyTypeChecker
	def get_link(self) -> enums.UpDownDirection:
		"""SCPI: [SOURce<HW>]:BB:ONEWeb:LINK \n
		Snippet: value: enums.UpDownDirection = driver.source.bb.oneweb.get_link() \n
		Sets the transmission direction. \n
			:return: link: UP| DOWN
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:BB:ONEWeb:LINK?')
		return Conversions.str_to_scalar_enum(response, enums.UpDownDirection)

	def set_link(self, link: enums.UpDownDirection) -> None:
		"""SCPI: [SOURce<HW>]:BB:ONEWeb:LINK \n
		Snippet: driver.source.bb.oneweb.set_link(link = enums.UpDownDirection.DOWN) \n
		Sets the transmission direction. \n
			:param link: UP| DOWN
		"""
		param = Conversions.enum_scalar_to_str(link, enums.UpDownDirection)
		self._core.io.write(f'SOURce<HwInstance>:BB:ONEWeb:LINK {param}')

	def preset(self) -> None:
		"""SCPI: [SOURce<HW>]:BB:ONEWeb:PRESet \n
		Snippet: driver.source.bb.oneweb.preset() \n
		Sets the parameters of the digital standard to their default values (*RST values specified for the commands) .
		Not affected is the state set with the command method RsSmw.Source.Bb.Oneweb.state. \n
		"""
		self._core.io.write(f'SOURce<HwInstance>:BB:ONEWeb:PRESet')

	def preset_with_opc(self) -> None:
		"""SCPI: [SOURce<HW>]:BB:ONEWeb:PRESet \n
		Snippet: driver.source.bb.oneweb.preset_with_opc() \n
		Sets the parameters of the digital standard to their default values (*RST values specified for the commands) .
		Not affected is the state set with the command method RsSmw.Source.Bb.Oneweb.state. \n
		Same as preset, but waits for the operation to complete before continuing further. Use the RsSmw.utilities.opc_timeout_set() to set the timeout value. \n
		"""
		self._core.io.write_with_opc(f'SOURce<HwInstance>:BB:ONEWeb:PRESet')

	def get_slength(self) -> int:
		"""SCPI: [SOURce<HW>]:BB:ONEWeb:SLENgth \n
		Snippet: value: int = driver.source.bb.oneweb.get_slength() \n
		Sets the sequence length of the signal in number of frames. The signal is calculated in advance and output in the
		arbitrary waveform generator. The maximum number of frames is calculated as follows: Max. No. of Frames = Arbitrary
		waveform memory size/(sampling rate x 10 ms) . \n
			:return: slength: integer Range: 1 to dynamic
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:BB:ONEWeb:SLENgth?')
		return Conversions.str_to_int(response)

	def set_slength(self, slength: int) -> None:
		"""SCPI: [SOURce<HW>]:BB:ONEWeb:SLENgth \n
		Snippet: driver.source.bb.oneweb.set_slength(slength = 1) \n
		Sets the sequence length of the signal in number of frames. The signal is calculated in advance and output in the
		arbitrary waveform generator. The maximum number of frames is calculated as follows: Max. No. of Frames = Arbitrary
		waveform memory size/(sampling rate x 10 ms) . \n
			:param slength: integer Range: 1 to dynamic
		"""
		param = Conversions.decimal_value_to_str(slength)
		self._core.io.write(f'SOURce<HwInstance>:BB:ONEWeb:SLENgth {param}')

	def get_state(self) -> bool:
		"""SCPI: [SOURce<HW>]:BB:ONEWeb:STATe \n
		Snippet: value: bool = driver.source.bb.oneweb.get_state() \n
		Activates the standard. \n
			:return: one_web_state: 0| 1| OFF| ON
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:BB:ONEWeb:STATe?')
		return Conversions.str_to_bool(response)

	def set_state(self, one_web_state: bool) -> None:
		"""SCPI: [SOURce<HW>]:BB:ONEWeb:STATe \n
		Snippet: driver.source.bb.oneweb.set_state(one_web_state = False) \n
		Activates the standard. \n
			:param one_web_state: 0| 1| OFF| ON
		"""
		param = Conversions.bool_to_str(one_web_state)
		self._core.io.write(f'SOURce<HwInstance>:BB:ONEWeb:STATe {param}')

	def get_version(self) -> str:
		"""SCPI: [SOURce]:BB:ONEWeb:VERSion \n
		Snippet: value: str = driver.source.bb.oneweb.get_version() \n
		No command help available \n
			:return: version: No help available
		"""
		response = self._core.io.query_str('SOURce:BB:ONEWeb:VERSion?')
		return trim_str_response(response)

	def clone(self) -> 'Oneweb':
		"""Clones the group by creating new object from it and its whole existing sub-groups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = Oneweb(self._core, self._base.parent)
		self._base.synchronize_repcaps(new_group)
		return new_group



from ...Internal.Core import Core
from ...Internal.CommandsGroup import CommandsGroup
from ...Internal.StructBase import StructBase
from ...Internal.ArgStruct import ArgStruct


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Sw:
	"""Sw commands group definition. 1 total commands, 0 Sub-groups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._base = CommandsGroup("sw", core, parent)

	# noinspection PyTypeChecker
	class ScmdStruct(StructBase):
		"""Structure for reading output parameters. Fields: \n
			- Scmd: str: No parameter help available
			- What_Is_This: str: No parameter help available"""
		__meta_args_list = [
			ArgStruct.scalar_str('Scmd'),
			ArgStruct.scalar_str('What_Is_This')]

		def __init__(self):
			StructBase.__init__(self, self)
			self.Scmd: str = None
			self.What_Is_This: str = None

	def get_scmd(self) -> ScmdStruct:
		"""SCPI: TEST<HW>:SW:SCMD \n
		Snippet: value: ScmdStruct = driver.test.sw.get_scmd() \n
		No command help available \n
			:return: structure: for return value, see the help for ScmdStruct structure arguments.
		"""
		return self._core.io.query_struct('TEST<HwInstance>:SW:SCMD?', self.__class__.ScmdStruct())

	def set_scmd(self, value: ScmdStruct) -> None:
		"""SCPI: TEST<HW>:SW:SCMD \n
		Snippet: driver.test.sw.set_scmd(value = ScmdStruct()) \n
		No command help available \n
			:param value: see the help for ScmdStruct structure arguments.
		"""
		self._core.io.write_struct('TEST<HwInstance>:SW:SCMD', value)



from ...........Internal.Core import Core
from ...........Internal.CommandsGroup import CommandsGroup


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Pucch:
	"""Pucch commands group definition. 10 total commands, 8 Sub-groups, 0 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._base = CommandsGroup("pucch", core, parent)

	@property
	def adMrs(self):
		"""adMrs commands group. 1 Sub-classes, 0 commands."""
		if not hasattr(self, '_adMrs'):
			from .AdMrs import AdMrs
			self._adMrs = AdMrs(self._core, self._base)
		return self._adMrs

	@property
	def bpsk(self):
		"""bpsk commands group. 1 Sub-classes, 0 commands."""
		if not hasattr(self, '_bpsk'):
			from .Bpsk import Bpsk
			self._bpsk = Bpsk(self._core, self._base)
		return self._bpsk

	@property
	def brind(self):
		"""brind commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_brind'):
			from .Brind import Brind
			self._brind = Brind(self._core, self._base)
		return self._brind

	@property
	def cpext(self):
		"""cpext commands group. 2 Sub-classes, 0 commands."""
		if not hasattr(self, '_cpext'):
			from .Cpext import Cpext
			self._cpext = Cpext(self._core, self._base)
		return self._cpext

	@property
	def hack(self):
		"""hack commands group. 1 Sub-classes, 0 commands."""
		if not hasattr(self, '_hack'):
			from .Hack import Hack
			self._hack = Hack(self._core, self._base)
		return self._hack

	@property
	def pdsharq(self):
		"""pdsharq commands group. 2 Sub-classes, 0 commands."""
		if not hasattr(self, '_pdsharq'):
			from .Pdsharq import Pdsharq
			self._pdsharq = Pdsharq(self._core, self._base)
		return self._pdsharq

	@property
	def uitl(self):
		"""uitl commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_uitl'):
			from .Uitl import Uitl
			self._uitl = Uitl(self._core, self._base)
		return self._uitl

	@property
	def ur16(self):
		"""ur16 commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_ur16'):
			from .Ur16 import Ur16
			self._ur16 = Ur16(self._core, self._base)
		return self._ur16

	def clone(self) -> 'Pucch':
		"""Clones the group by creating new object from it and its whole existing sub-groups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = Pucch(self._core, self._base.parent)
		self._base.synchronize_repcaps(new_group)
		return new_group



from ....Internal.Core import Core
from ....Internal.CommandsGroup import CommandsGroup
from ....Internal import Conversions
from ....Internal.Types import DataType
from ....Internal.ArgSingleList import ArgSingleList
from ....Internal.ArgSingle import ArgSingle
from .... import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class State:
	"""State commands group definition. 1 total commands, 0 Sub-groups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._base = CommandsGroup("state", core, parent)

	def set(self, state: bool, key: int = None, level=repcap.Level.Default) -> None:
		"""SCPI: SYSTem:PROTect<CH>:[STATe] \n
		Snippet: driver.system.protect.state.set(state = False, key = 1, level = repcap.Level.Default) \n
		Activates and deactivates the specified protection level. \n
			:param state: 0| 1| OFF| ON
			:param key: integer The respective functions are disabled when the protection level is activated. No password is required for activation of a level. A password must be entered to deactivate the protection level. The default password for the first level is 123456. This protection level is required to unlock internal adjustments for example.
			:param level: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Protect')"""
		param = ArgSingleList().compose_cmd_string(ArgSingle('state', state, DataType.Boolean), ArgSingle('key', key, DataType.Integer, True))
		level_cmd_val = self._base.get_repcap_cmd_value(level, repcap.Level)
		self._core.io.write(f'SYSTem:PROTect{level_cmd_val}:STATe {param}'.rstrip())

	def get(self, level=repcap.Level.Default) -> bool:
		"""SCPI: SYSTem:PROTect<CH>:[STATe] \n
		Snippet: value: bool = driver.system.protect.state.get(level = repcap.Level.Default) \n
		Activates and deactivates the specified protection level. \n
			:param level: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Protect')
			:return: state: 0| 1| OFF| ON"""
		level_cmd_val = self._base.get_repcap_cmd_value(level, repcap.Level)
		response = self._core.io.query_str(f'SYSTem:PROTect{level_cmd_val}:STATe?')
		return Conversions.str_to_bool(response)



from .............Internal.Core import Core
from .............Internal.CommandsGroup import CommandsGroup


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Dmrs:
	"""Dmrs commands group definition. 7 total commands, 7 Sub-groups, 0 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._base = CommandsGroup("dmrs", core, parent)

	@property
	def length(self):
		"""length commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_length'):
			from .Length import Length
			self._length = Length(self._core, self._base)
		return self._length

	@property
	def nsid(self):
		"""nsid commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_nsid'):
			from .Nsid import Nsid
			self._nsid = Nsid(self._core, self._base)
		return self._nsid

	@property
	def power(self):
		"""power commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_power'):
			from .Power import Power
			self._power = Power(self._core, self._base)
		return self._power

	@property
	def seqGen(self):
		"""seqGen commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_seqGen'):
			from .SeqGen import SeqGen
			self._seqGen = SeqGen(self._core, self._base)
		return self._seqGen

	@property
	def seqHopping(self):
		"""seqHopping commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_seqHopping'):
			from .SeqHopping import SeqHopping
			self._seqHopping = SeqHopping(self._core, self._base)
		return self._seqHopping

	@property
	def sltSymbols(self):
		"""sltSymbols commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_sltSymbols'):
			from .SltSymbols import SltSymbols
			self._sltSymbols = SltSymbols(self._core, self._base)
		return self._sltSymbols

	@property
	def apSelect(self):
		"""apSelect commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_apSelect'):
			from .ApSelect import ApSelect
			self._apSelect = ApSelect(self._core, self._base)
		return self._apSelect

	def clone(self) -> 'Dmrs':
		"""Clones the group by creating new object from it and its whole existing sub-groups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = Dmrs(self._core, self._base.parent)
		self._base.synchronize_repcaps(new_group)
		return new_group



from .......Internal.Core import Core
from .......Internal.CommandsGroup import CommandsGroup
from .......Internal import Conversions
from ....... import enums


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Cchannel:
	"""Cchannel commands group definition. 5 total commands, 1 Sub-groups, 3 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._base = CommandsGroup("cchannel", core, parent)

	@property
	def revision(self):
		"""revision commands group. 0 Sub-classes, 2 commands."""
		if not hasattr(self, '_revision'):
			from .Revision import Revision
			self._revision = Revision(self._core, self._base)
		return self._revision

	def get_ps_offset(self) -> int:
		"""SCPI: [SOURce<HW>]:BB:EVDO:ANETwork:CCHannel:PSOFfset \n
		Snippet: value: int = driver.source.bb.evdo.anetwork.cchannel.get_ps_offset() \n
		Sets the offset (in slots) from the start of control channel cycle to the start of the synchronous message capsule that
		contains the Sync Message. \n
			:return: ps_offset: integer Range: 0 to 3
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:BB:EVDO:ANETwork:CCHannel:PSOFfset?')
		return Conversions.str_to_int(response)

	def set_ps_offset(self, ps_offset: int) -> None:
		"""SCPI: [SOURce<HW>]:BB:EVDO:ANETwork:CCHannel:PSOFfset \n
		Snippet: driver.source.bb.evdo.anetwork.cchannel.set_ps_offset(ps_offset = 1) \n
		Sets the offset (in slots) from the start of control channel cycle to the start of the synchronous message capsule that
		contains the Sync Message. \n
			:param ps_offset: integer Range: 0 to 3
		"""
		param = Conversions.decimal_value_to_str(ps_offset)
		self._core.io.write(f'SOURce<HwInstance>:BB:EVDO:ANETwork:CCHannel:PSOFfset {param}')

	# noinspection PyTypeChecker
	def get_rate(self) -> enums.EvdoDataRate:
		"""SCPI: [SOURce<HW>]:BB:EVDO:ANETwork:CCHannel:RATE \n
		Snippet: value: enums.EvdoDataRate = driver.source.bb.evdo.anetwork.cchannel.get_rate() \n
		Sets the rate that the control channel messages are transmitted at. \n
			:return: rate: DR4K8| DR9K6| DR19K2| DR38K4| DR76K8| DR153K6| DR307K2| DR614K4| DR921K6| DR1228K8| DR1536K| DR1843K2| DR2457K6| DR3072K| DR460K8| DR768K| DR1075K2| DR2150K4| DR3686K4| DR4300K8| DR4915K2
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:BB:EVDO:ANETwork:CCHannel:RATE?')
		return Conversions.str_to_scalar_enum(response, enums.EvdoDataRate)

	def set_rate(self, rate: enums.EvdoDataRate) -> None:
		"""SCPI: [SOURce<HW>]:BB:EVDO:ANETwork:CCHannel:RATE \n
		Snippet: driver.source.bb.evdo.anetwork.cchannel.set_rate(rate = enums.EvdoDataRate.DR1075K2) \n
		Sets the rate that the control channel messages are transmitted at. \n
			:param rate: DR4K8| DR9K6| DR19K2| DR38K4| DR76K8| DR153K6| DR307K2| DR614K4| DR921K6| DR1228K8| DR1536K| DR1843K2| DR2457K6| DR3072K| DR460K8| DR768K| DR1075K2| DR2150K4| DR3686K4| DR4300K8| DR4915K2
		"""
		param = Conversions.enum_scalar_to_str(rate, enums.EvdoDataRate)
		self._core.io.write(f'SOURce<HwInstance>:BB:EVDO:ANETwork:CCHannel:RATE {param}')

	def get_state(self) -> bool:
		"""SCPI: [SOURce<HW>]:BB:EVDO:ANETwork:CCHannel:STATe \n
		Snippet: value: bool = driver.source.bb.evdo.anetwork.cchannel.get_state() \n
		Enables or disables the control channel messages. \n
			:return: state: 0| 1| OFF| ON
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:BB:EVDO:ANETwork:CCHannel:STATe?')
		return Conversions.str_to_bool(response)

	def set_state(self, state: bool) -> None:
		"""SCPI: [SOURce<HW>]:BB:EVDO:ANETwork:CCHannel:STATe \n
		Snippet: driver.source.bb.evdo.anetwork.cchannel.set_state(state = False) \n
		Enables or disables the control channel messages. \n
			:param state: 0| 1| OFF| ON
		"""
		param = Conversions.bool_to_str(state)
		self._core.io.write(f'SOURce<HwInstance>:BB:EVDO:ANETwork:CCHannel:STATe {param}')

	def clone(self) -> 'Cchannel':
		"""Clones the group by creating new object from it and its whole existing sub-groups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = Cchannel(self._core, self._base.parent)
		self._base.synchronize_repcaps(new_group)
		return new_group



from .........Internal.Core import Core
from .........Internal.CommandsGroup import CommandsGroup
from .........Internal import Conversions
from ......... import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Cregion:
	"""Cregion commands group definition. 1 total commands, 0 Sub-groups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._base = CommandsGroup("cregion", core, parent)

	def set(self, control_region: int, subframeNull=repcap.SubframeNull.Default) -> None:
		"""SCPI: [SOURce<HW>]:BB:V5G:DL:[SUBF<ST0>]:ENCC:PCFich:CREGion \n
		Snippet: driver.source.bb.v5G.downlink.subf.encc.pcfich.cregion.set(control_region = 1, subframeNull = repcap.SubframeNull.Default) \n
		No command help available \n
			:param control_region: No help available
			:param subframeNull: optional repeated capability selector. Default value: Nr0 (settable in the interface 'Subf')"""
		param = Conversions.decimal_value_to_str(control_region)
		subframeNull_cmd_val = self._base.get_repcap_cmd_value(subframeNull, repcap.SubframeNull)
		self._core.io.write(f'SOURce<HwInstance>:BB:V5G:DL:SUBF{subframeNull_cmd_val}:ENCC:PCFich:CREGion {param}')

	def get(self, subframeNull=repcap.SubframeNull.Default) -> int:
		"""SCPI: [SOURce<HW>]:BB:V5G:DL:[SUBF<ST0>]:ENCC:PCFich:CREGion \n
		Snippet: value: int = driver.source.bb.v5G.downlink.subf.encc.pcfich.cregion.get(subframeNull = repcap.SubframeNull.Default) \n
		No command help available \n
			:param subframeNull: optional repeated capability selector. Default value: Nr0 (settable in the interface 'Subf')
			:return: control_region: No help available"""
		subframeNull_cmd_val = self._base.get_repcap_cmd_value(subframeNull, repcap.SubframeNull)
		response = self._core.io.query_str(f'SOURce<HwInstance>:BB:V5G:DL:SUBF{subframeNull_cmd_val}:ENCC:PCFich:CREGion?')
		return Conversions.str_to_int(response)



from .......Internal.Core import Core
from .......Internal.CommandsGroup import CommandsGroup
from .......Internal import Conversions
from ....... import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Conflict:
	"""Conflict commands group definition. 1 total commands, 0 Sub-groups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._base = CommandsGroup("conflict", core, parent)

	def get(self, carrier=repcap.Carrier.Default) -> bool:
		"""SCPI: [SOURce<HW>]:BB:ARBitrary:MCARrier:CARRier<CH>:CONFlict \n
		Snippet: value: bool = driver.source.bb.arbitrary.mcarrier.carrier.conflict.get(carrier = repcap.Carrier.Default) \n
		Queries carrier conflicts. A conflict arises when the carriers overlap. \n
			:param carrier: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Mcarrier')
			:return: conflict: 0| 1| OFF| ON 0 No conflict"""
		carrier_cmd_val = self._base.get_repcap_cmd_value(carrier, repcap.Carrier)
		response = self._core.io.query_str(f'SOURce<HwInstance>:BB:ARBitrary:MCARrier:CARRier{carrier_cmd_val}:CONFlict?')
		return Conversions.str_to_bool(response)



from ........Internal.Core import Core
from ........Internal.CommandsGroup import CommandsGroup
from ........Internal import Conversions
from ........ import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Codewords:
	"""Codewords commands group definition. 1 total commands, 0 Sub-groups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._base = CommandsGroup("codewords", core, parent)

	def set(self, codewords: int, subframeNull=repcap.SubframeNull.Default, allocationNull=repcap.AllocationNull.Default) -> None:
		"""SCPI: [SOURce<HW>]:BB:EUTRa:DL:[SUBF<ST0>]:ALLoc<CH0>:CODWords \n
		Snippet: driver.source.bb.eutra.downlink.subf.alloc.codewords.set(codewords = 1, subframeNull = repcap.SubframeNull.Default, allocationNull = repcap.AllocationNull.Default) \n
		Sets the number of codewords for an allocation. Two codewords are available for global MIMO configuration with two or
		more antennas. \n
			:param codewords: 1| 2 Range: 1 to 2
			:param subframeNull: optional repeated capability selector. Default value: Nr0 (settable in the interface 'Subf')
			:param allocationNull: optional repeated capability selector. Default value: Nr0 (settable in the interface 'Alloc')"""
		param = Conversions.decimal_value_to_str(codewords)
		subframeNull_cmd_val = self._base.get_repcap_cmd_value(subframeNull, repcap.SubframeNull)
		allocationNull_cmd_val = self._base.get_repcap_cmd_value(allocationNull, repcap.AllocationNull)
		self._core.io.write(f'SOURce<HwInstance>:BB:EUTRa:DL:SUBF{subframeNull_cmd_val}:ALLoc{allocationNull_cmd_val}:CODWords {param}')

	def get(self, subframeNull=repcap.SubframeNull.Default, allocationNull=repcap.AllocationNull.Default) -> int:
		"""SCPI: [SOURce<HW>]:BB:EUTRa:DL:[SUBF<ST0>]:ALLoc<CH0>:CODWords \n
		Snippet: value: int = driver.source.bb.eutra.downlink.subf.alloc.codewords.get(subframeNull = repcap.SubframeNull.Default, allocationNull = repcap.AllocationNull.Default) \n
		Sets the number of codewords for an allocation. Two codewords are available for global MIMO configuration with two or
		more antennas. \n
			:param subframeNull: optional repeated capability selector. Default value: Nr0 (settable in the interface 'Subf')
			:param allocationNull: optional repeated capability selector. Default value: Nr0 (settable in the interface 'Alloc')
			:return: codewords: 1| 2 Range: 1 to 2"""
		subframeNull_cmd_val = self._base.get_repcap_cmd_value(subframeNull, repcap.SubframeNull)
		allocationNull_cmd_val = self._base.get_repcap_cmd_value(allocationNull, repcap.AllocationNull)
		response = self._core.io.query_str(f'SOURce<HwInstance>:BB:EUTRa:DL:SUBF{subframeNull_cmd_val}:ALLoc{allocationNull_cmd_val}:CODWords?')
		return Conversions.str_to_int(response)



from ....Internal.Core import Core
from ....Internal.CommandsGroup import CommandsGroup
from ....Internal import Conversions
from ....Internal.RepeatedCapability import RepeatedCapability
from .... import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Am:
	"""Am commands group definition. 6 total commands, 3 Sub-groups, 2 group commands
	Repeated Capability: GeneratorIx, default value after init: GeneratorIx.Nr1"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._base = CommandsGroup("am", core, parent)
		self._base.rep_cap = RepeatedCapability(self._base.group_name, 'repcap_generatorIx_get', 'repcap_generatorIx_set', repcap.GeneratorIx.Nr1)

	def repcap_generatorIx_set(self, enum_value: repcap.GeneratorIx) -> None:
		"""Repeated Capability default value numeric suffix.
		This value is used, if you do not explicitely set it in the child set/get methods, or if you leave it to GeneratorIx.Default
		Default value after init: GeneratorIx.Nr1"""
		self._base.set_repcap_enum_value(enum_value)

	def repcap_generatorIx_get(self) -> repcap.GeneratorIx:
		"""Returns the current default repeated capability for the child set/get methods"""
		# noinspection PyTypeChecker
		return self._base.get_repcap_enum_value()

	@property
	def depth(self):
		"""depth commands group. 0 Sub-classes, 2 commands."""
		if not hasattr(self, '_depth'):
			from .Depth import Depth
			self._depth = Depth(self._core, self._base)
		return self._depth

	@property
	def deviation(self):
		"""deviation commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_deviation'):
			from .Deviation import Deviation
			self._deviation = Deviation(self._core, self._base)
		return self._deviation

	@property
	def state(self):
		"""state commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_state'):
			from .State import State
			self._state = State(self._core, self._base)
		return self._state

	def get_ratio(self) -> float:
		"""SCPI: [SOURce<HW>]:AM:RATio \n
		Snippet: value: float = driver.source.am.get_ratio() \n
		Sets the deviation ratio (path#2 to path#1) in percent. \n
			:return: ratio: float Range: 0 to 100
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:AM:RATio?')
		return Conversions.str_to_float(response)

	def set_ratio(self, ratio: float) -> None:
		"""SCPI: [SOURce<HW>]:AM:RATio \n
		Snippet: driver.source.am.set_ratio(ratio = 1.0) \n
		Sets the deviation ratio (path#2 to path#1) in percent. \n
			:param ratio: float Range: 0 to 100
		"""
		param = Conversions.decimal_value_to_str(ratio)
		self._core.io.write(f'SOURce<HwInstance>:AM:RATio {param}')

	def get_sensitivity(self) -> float:
		"""SCPI: [SOURce<HW>]:AM:SENSitivity \n
		Snippet: value: float = driver.source.am.get_sensitivity() \n
		Sets the sensitivity of the external signal source for amplitude modulation in %/V. \n
			:return: sensitivity: float Range: 0 to 100
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:AM:SENSitivity?')
		return Conversions.str_to_float(response)

	def clone(self) -> 'Am':
		"""Clones the group by creating new object from it and its whole existing sub-groups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = Am(self._core, self._base.parent)
		self._base.synchronize_repcaps(new_group)
		return new_group



from .......Internal.Core import Core
from .......Internal.CommandsGroup import CommandsGroup
from .......Internal import Conversions
from .......Internal.RepeatedCapability import RepeatedCapability
from ....... import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Mpdu:
	"""Mpdu commands group definition. 5 total commands, 1 Sub-groups, 1 group commands
	Repeated Capability: MacPdu, default value after init: MacPdu.Nr1"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._base = CommandsGroup("mpdu", core, parent)
		self._base.rep_cap = RepeatedCapability(self._base.group_name, 'repcap_macPdu_get', 'repcap_macPdu_set', repcap.MacPdu.Nr1)

	def repcap_macPdu_set(self, enum_value: repcap.MacPdu) -> None:
		"""Repeated Capability default value numeric suffix.
		This value is used, if you do not explicitely set it in the child set/get methods, or if you leave it to MacPdu.Default
		Default value after init: MacPdu.Nr1"""
		self._base.set_repcap_enum_value(enum_value)

	def repcap_macPdu_get(self) -> repcap.MacPdu:
		"""Returns the current default repeated capability for the child set/get methods"""
		# noinspection PyTypeChecker
		return self._base.get_repcap_enum_value()

	@property
	def data(self):
		"""data commands group. 4 Sub-classes, 0 commands."""
		if not hasattr(self, '_data'):
			from .Data import Data
			self._data = Data(self._core, self._base)
		return self._data

	def get_count(self) -> int:
		"""SCPI: [SOURce<HW>]:BB:WLAD:PCONfig:MPDU:COUNt \n
		Snippet: value: int = driver.source.bb.wlad.pconfig.mpdu.get_count() \n
		Sets the number of MPDUs in the frame. \n
			:return: count: integer Range: 1 to 64
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:BB:WLAD:PCONfig:MPDU:COUNt?')
		return Conversions.str_to_int(response)

	def set_count(self, count: int) -> None:
		"""SCPI: [SOURce<HW>]:BB:WLAD:PCONfig:MPDU:COUNt \n
		Snippet: driver.source.bb.wlad.pconfig.mpdu.set_count(count = 1) \n
		Sets the number of MPDUs in the frame. \n
			:param count: integer Range: 1 to 64
		"""
		param = Conversions.decimal_value_to_str(count)
		self._core.io.write(f'SOURce<HwInstance>:BB:WLAD:PCONfig:MPDU:COUNt {param}')

	def clone(self) -> 'Mpdu':
		"""Clones the group by creating new object from it and its whole existing sub-groups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = Mpdu(self._core, self._base.parent)
		self._base.synchronize_repcaps(new_group)
		return new_group



from .......Internal.Core import Core
from .......Internal.CommandsGroup import CommandsGroup
from .......Internal import Conversions


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Ciq:
	"""Ciq commands group definition. 4 total commands, 1 Sub-groups, 2 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._base = CommandsGroup("ciq", core, parent)

	@property
	def create(self):
		"""create commands group. 0 Sub-classes, 2 commands."""
		if not hasattr(self, '_create'):
			from .Create import Create
			self._create = Create(self._core, self._base)
		return self._create

	def get_icomponent(self) -> float:
		"""SCPI: [SOURce<HW>]:BB:ARBitrary:TSIGnal:CIQ:I \n
		Snippet: value: float = driver.source.bb.arbitrary.tsignal.ciq.get_icomponent() \n
		Sets the value for the I and Q component of the test signal \n
			:return: ipart: No help available
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:BB:ARBitrary:TSIGnal:CIQ:I?')
		return Conversions.str_to_float(response)

	def set_icomponent(self, ipart: float) -> None:
		"""SCPI: [SOURce<HW>]:BB:ARBitrary:TSIGnal:CIQ:I \n
		Snippet: driver.source.bb.arbitrary.tsignal.ciq.set_icomponent(ipart = 1.0) \n
		Sets the value for the I and Q component of the test signal \n
			:param ipart: float Range: -1 to 1, Unit: FS
		"""
		param = Conversions.decimal_value_to_str(ipart)
		self._core.io.write(f'SOURce<HwInstance>:BB:ARBitrary:TSIGnal:CIQ:I {param}')

	def get_qcomponent(self) -> float:
		"""SCPI: [SOURce<HW>]:BB:ARBitrary:TSIGnal:CIQ:Q \n
		Snippet: value: float = driver.source.bb.arbitrary.tsignal.ciq.get_qcomponent() \n
		Sets the value for the I and Q component of the test signal \n
			:return: tsig: float Range: -1 to 1, Unit: FS
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:BB:ARBitrary:TSIGnal:CIQ:Q?')
		return Conversions.str_to_float(response)

	def set_qcomponent(self, tsig: float) -> None:
		"""SCPI: [SOURce<HW>]:BB:ARBitrary:TSIGnal:CIQ:Q \n
		Snippet: driver.source.bb.arbitrary.tsignal.ciq.set_qcomponent(tsig = 1.0) \n
		Sets the value for the I and Q component of the test signal \n
			:param tsig: float Range: -1 to 1, Unit: FS
		"""
		param = Conversions.decimal_value_to_str(tsig)
		self._core.io.write(f'SOURce<HwInstance>:BB:ARBitrary:TSIGnal:CIQ:Q {param}')

	def clone(self) -> 'Ciq':
		"""Clones the group by creating new object from it and its whole existing sub-groups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = Ciq(self._core, self._base.parent)
		self._base.synchronize_repcaps(new_group)
		return new_group



from .......Internal.Core import Core
from .......Internal.CommandsGroup import CommandsGroup
from .......Internal.Utilities import trim_str_response
from ....... import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Comment:
	"""Comment commands group definition. 1 total commands, 0 Sub-groups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._base = CommandsGroup("comment", core, parent)

	def get(self, sequencer=repcap.Sequencer.Default) -> str:
		"""SCPI: [SOURce<HW>]:BB:ESEQuencer:DFINding:[SEQuencer<ST>]:COMMent \n
		Snippet: value: str = driver.source.bb.esequencer.dfinding.sequencer.comment.get(sequencer = repcap.Sequencer.Default) \n
		Queries the information on the loaded pulse sequencer file. \n
			:param sequencer: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Sequencer')
			:return: comment: string"""
		sequencer_cmd_val = self._base.get_repcap_cmd_value(sequencer, repcap.Sequencer)
		response = self._core.io.query_str(f'SOURce<HwInstance>:BB:ESEQuencer:DFINding:SEQuencer{sequencer_cmd_val}:COMMent?')
		return trim_str_response(response)



from .......Internal.Core import Core
from .......Internal.CommandsGroup import CommandsGroup
from .......Internal import Conversions
from ....... import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Predefined:
	"""Predefined commands group definition. 2 total commands, 1 Sub-groups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._base = CommandsGroup("predefined", core, parent)

	@property
	def catalog(self):
		"""catalog commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_catalog'):
			from .Catalog import Catalog
			self._catalog = Catalog(self._core, self._base)
		return self._catalog

	def load(self, filename: str, frameIx=repcap.FrameIx.Default) -> None:
		"""SCPI: [SOURce<HW>]:BB:GSM:[FRAMe<DI>]:PREDefined:LOAD \n
		Snippet: driver.source.bb.gsm.frame.predefined.load(filename = '1', frameIx = repcap.FrameIx.Default) \n
		This command loads the selected file with predefined frame settings. The directory is pre-set, therefore a path cannot be
		specified. \n
			:param filename: string
			:param frameIx: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Frame')"""
		param = Conversions.value_to_quoted_str(filename)
		frameIx_cmd_val = self._base.get_repcap_cmd_value(frameIx, repcap.FrameIx)
		self._core.io.write(f'SOURce<HwInstance>:BB:GSM:FRAMe{frameIx_cmd_val}:PREDefined:LOAD {param}')

	def clone(self) -> 'Predefined':
		"""Clones the group by creating new object from it and its whole existing sub-groups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = Predefined(self._core, self._base.parent)
		self._base.synchronize_repcaps(new_group)
		return new_group



from typing import List

from ...Internal.Core import Core
from ...Internal.CommandsGroup import CommandsGroup
from ...Internal import Conversions


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Gpib:
	"""Gpib commands group definition. 2 total commands, 0 Sub-groups, 2 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._base = CommandsGroup("gpib", core, parent)

	def get_address(self) -> List[int]:
		"""SCPI: INSTruments:GPIB:ADDRess \n
		Snippet: value: List[int] = driver.instruments.gpib.get_address() \n
		No command help available \n
			:return: serial: No help available
		"""
		response = self._core.io.query_bin_or_ascii_int_list('INSTruments:GPIB:ADDRess?')
		return response

	def set_address(self, serial: List[int]) -> None:
		"""SCPI: INSTruments:GPIB:ADDRess \n
		Snippet: driver.instruments.gpib.set_address(serial = [1, 2, 3]) \n
		No command help available \n
			:param serial: No help available
		"""
		param = Conversions.list_to_csv_str(serial)
		self._core.io.write(f'INSTruments:GPIB:ADDRess {param}')

	def get_board(self) -> List[int]:
		"""SCPI: INSTruments:GPIB:BOARd \n
		Snippet: value: List[int] = driver.instruments.gpib.get_board() \n
		No command help available \n
			:return: board: No help available
		"""
		response = self._core.io.query_bin_or_ascii_int_list('INSTruments:GPIB:BOARd?')
		return response

	def set_board(self, board: List[int]) -> None:
		"""SCPI: INSTruments:GPIB:BOARd \n
		Snippet: driver.instruments.gpib.set_board(board = [1, 2, 3]) \n
		No command help available \n
			:param board: No help available
		"""
		param = Conversions.list_to_csv_str(board)
		self._core.io.write(f'INSTruments:GPIB:BOARd {param}')



from ......Internal.Core import Core
from ......Internal.CommandsGroup import CommandsGroup


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Scwi:
	"""Scwi commands group definition. 11 total commands, 2 Sub-groups, 0 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._base = CommandsGroup("scwi", core, parent)

	@property
	def cluster(self):
		"""cluster commands group. 5 Sub-classes, 0 commands."""
		if not hasattr(self, '_cluster'):
			from .Cluster import Cluster
			self._cluster = Cluster(self._core, self._base)
		return self._cluster

	@property
	def tap(self):
		"""tap commands group. 2 Sub-classes, 0 commands."""
		if not hasattr(self, '_tap'):
			from .Tap import Tap
			self._tap = Tap(self._core, self._base)
		return self._tap

	def clone(self) -> 'Scwi':
		"""Clones the group by creating new object from it and its whole existing sub-groups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = Scwi(self._core, self._base.parent)
		self._base.synchronize_repcaps(new_group)
		return new_group



from ........Internal.Core import Core
from ........Internal.CommandsGroup import CommandsGroup
from ........Internal import Conversions
from ........ import enums


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Dpdch:
	"""Dpdch commands group definition. 37 total commands, 4 Sub-groups, 4 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._base = CommandsGroup("dpdch", core, parent)

	@property
	def ccoding(self):
		"""ccoding commands group. 1 Sub-classes, 2 commands."""
		if not hasattr(self, '_ccoding'):
			from .Ccoding import Ccoding
			self._ccoding = Ccoding(self._core, self._base)
		return self._ccoding

	@property
	def derror(self):
		"""derror commands group. 2 Sub-classes, 0 commands."""
		if not hasattr(self, '_derror'):
			from .Derror import Derror
			self._derror = Derror(self._core, self._base)
		return self._derror

	@property
	def tchannel(self):
		"""tchannel commands group. 9 Sub-classes, 0 commands."""
		if not hasattr(self, '_tchannel'):
			from .Tchannel import Tchannel
			self._tchannel = Tchannel(self._core, self._base)
		return self._tchannel

	@property
	def dpControl(self):
		"""dpControl commands group. 2 Sub-classes, 7 commands."""
		if not hasattr(self, '_dpControl'):
			from .DpControl import DpControl
			self._dpControl = DpControl(self._core, self._base)
		return self._dpControl

	def get_bp_frame(self) -> int:
		"""SCPI: [SOURce<HW>]:BB:W3GPp:MSTation:ENHanced:DPDCh:BPFRame \n
		Snippet: value: int = driver.source.bb.w3Gpp.mstation.enhanced.dpdch.get_bp_frame() \n
		The command queries the number of data bits in the DPDCH component of the frame at the physical layer. The number of data
		bits depends on the overall symbol rate. \n
			:return: bp_frame: integer Range: 150 to 9600
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:BB:W3GPp:MSTation:ENHanced:DPDCh:BPFRame?')
		return Conversions.str_to_int(response)

	def get_interleaver_2(self) -> bool:
		"""SCPI: [SOURce<HW>]:BB:W3GPp:MSTation:ENHanced:DPDCh:INTerleaver2 \n
		Snippet: value: bool = driver.source.bb.w3Gpp.mstation.enhanced.dpdch.get_interleaver_2() \n
		The command activates or deactivates channel coding interleaver state 2 for all the transport channels. Interleaver state
		1 can be activated and deactivated for each channel individually
		([:SOURce<hw>]:BB:W3GPp:MSTation:ENHanced:DPDCh:TCHannel<di0>:INTerleaver) . Note: The interleaver states do not cause
		the symbol rate to change \n
			:return: interleaver_2: 0| 1| OFF| ON
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:BB:W3GPp:MSTation:ENHanced:DPDCh:INTerleaver2?')
		return Conversions.str_to_bool(response)

	def set_interleaver_2(self, interleaver_2: bool) -> None:
		"""SCPI: [SOURce<HW>]:BB:W3GPp:MSTation:ENHanced:DPDCh:INTerleaver2 \n
		Snippet: driver.source.bb.w3Gpp.mstation.enhanced.dpdch.set_interleaver_2(interleaver_2 = False) \n
		The command activates or deactivates channel coding interleaver state 2 for all the transport channels. Interleaver state
		1 can be activated and deactivated for each channel individually
		([:SOURce<hw>]:BB:W3GPp:MSTation:ENHanced:DPDCh:TCHannel<di0>:INTerleaver) . Note: The interleaver states do not cause
		the symbol rate to change \n
			:param interleaver_2: 0| 1| OFF| ON
		"""
		param = Conversions.bool_to_str(interleaver_2)
		self._core.io.write(f'SOURce<HwInstance>:BB:W3GPp:MSTation:ENHanced:DPDCh:INTerleaver2 {param}')

	# noinspection PyTypeChecker
	def get_orate(self) -> enums.SymbRate:
		"""SCPI: [SOURce<HW>]:BB:W3GPp:MSTation:ENHanced:DPDCh:ORATe \n
		Snippet: value: enums.SymbRate = driver.source.bb.w3Gpp.mstation.enhanced.dpdch.get_orate() \n
		The command queries the overall symbol rate (Overall Symbol Rate) of the enhanced channels. The value is set with the
		command [:SOURce<hw>]:BB:W3GPp:MSTation<st>:DPDCh:ORATe. This setting also defines the number of active channels, their
		symbol rates and channelization codes. \n
			:return: orate: D15K| D30K| D60K| D120k| D240k| D480k| D960k| D1920k| D2880k| D3840k| D4800k| D5760k
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:BB:W3GPp:MSTation:ENHanced:DPDCh:ORATe?')
		return Conversions.str_to_scalar_enum(response, enums.SymbRate)

	def set_orate(self, orate: enums.SymbRate) -> None:
		"""SCPI: [SOURce<HW>]:BB:W3GPp:MSTation:ENHanced:DPDCh:ORATe \n
		Snippet: driver.source.bb.w3Gpp.mstation.enhanced.dpdch.set_orate(orate = enums.SymbRate.D120k) \n
		The command queries the overall symbol rate (Overall Symbol Rate) of the enhanced channels. The value is set with the
		command [:SOURce<hw>]:BB:W3GPp:MSTation<st>:DPDCh:ORATe. This setting also defines the number of active channels, their
		symbol rates and channelization codes. \n
			:param orate: D15K| D30K| D60K| D120k| D240k| D480k| D960k| D1920k| D2880k| D3840k| D4800k| D5760k
		"""
		param = Conversions.enum_scalar_to_str(orate, enums.SymbRate)
		self._core.io.write(f'SOURce<HwInstance>:BB:W3GPp:MSTation:ENHanced:DPDCh:ORATe {param}')

	def get_state(self) -> bool:
		"""SCPI: [SOURce<HW>]:BB:W3GPp:MSTation:ENHanced:DPDCh:STATe \n
		Snippet: value: bool = driver.source.bb.w3Gpp.mstation.enhanced.dpdch.get_state() \n
		Queries the enhanced state of the station. \n
			:return: state: 0| 1| OFF| ON
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:BB:W3GPp:MSTation:ENHanced:DPDCh:STATe?')
		return Conversions.str_to_bool(response)

	def set_state(self, state: bool) -> None:
		"""SCPI: [SOURce<HW>]:BB:W3GPp:MSTation:ENHanced:DPDCh:STATe \n
		Snippet: driver.source.bb.w3Gpp.mstation.enhanced.dpdch.set_state(state = False) \n
		Queries the enhanced state of the station. \n
			:param state: 0| 1| OFF| ON
		"""
		param = Conversions.bool_to_str(state)
		self._core.io.write(f'SOURce<HwInstance>:BB:W3GPp:MSTation:ENHanced:DPDCh:STATe {param}')

	def clone(self) -> 'Dpdch':
		"""Clones the group by creating new object from it and its whole existing sub-groups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = Dpdch(self._core, self._base.parent)
		self._base.synchronize_repcaps(new_group)
		return new_group



from ........Internal.Core import Core
from ........Internal.CommandsGroup import CommandsGroup
from ........Internal import Conversions
from ........ import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Exec:
	"""Exec commands group definition. 1 total commands, 0 Sub-groups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._base = CommandsGroup("exec", core, parent)

	def get(self, sequencer=repcap.Sequencer.Default) -> float:
		"""SCPI: [SOURce<HW>]:BB:ESEQuencer:RTCI:[SEQuencer<ST>]:STReam:EXEC \n
		Snippet: value: float = driver.source.bb.esequencer.rtci.sequencer.stream.exec.get(sequencer = repcap.Sequencer.Default) \n
		Query data from streaming interface registers for system time, write count, read count, executed PDWs, dropped PDWs,
		buffer filled and buffer remain information. \n
			:param sequencer: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Sequencer')
			:return: value: float"""
		sequencer_cmd_val = self._base.get_repcap_cmd_value(sequencer, repcap.Sequencer)
		response = self._core.io.query_str(f'SOURce<HwInstance>:BB:ESEQuencer:RTCI:SEQuencer{sequencer_cmd_val}:STReam:EXEC?')
		return Conversions.str_to_float(response)



from .......Internal.Core import Core
from .......Internal.CommandsGroup import CommandsGroup
from .......Internal import Conversions
from .......Internal.Utilities import trim_str_response
from ....... import enums


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class IpAddress:
	"""IpAddress commands group definition. 3 total commands, 1 Sub-groups, 2 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._base = CommandsGroup("ipAddress", core, parent)

	@property
	def subnet(self):
		"""subnet commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_subnet'):
			from .Subnet import Subnet
			self._subnet = Subnet(self._core, self._base)
		return self._subnet

	# noinspection PyTypeChecker
	def get_mode(self) -> enums.NetMode:
		"""SCPI: SYSTem:COMMunicate:BB<HW>:NETWork:IPADdress:MODE \n
		Snippet: value: enums.NetMode = driver.system.communicate.bb.network.ipAddress.get_mode() \n
		Selects manual or automatic setting of the IP address. \n
			:return: mode: AUTO| STATic
		"""
		response = self._core.io.query_str('SYSTem:COMMunicate:BB<HwInstance>:NETWork:IPADdress:MODE?')
		return Conversions.str_to_scalar_enum(response, enums.NetMode)

	def set_mode(self, mode: enums.NetMode) -> None:
		"""SCPI: SYSTem:COMMunicate:BB<HW>:NETWork:IPADdress:MODE \n
		Snippet: driver.system.communicate.bb.network.ipAddress.set_mode(mode = enums.NetMode.AUTO) \n
		Selects manual or automatic setting of the IP address. \n
			:param mode: AUTO| STATic
		"""
		param = Conversions.enum_scalar_to_str(mode, enums.NetMode)
		self._core.io.write(f'SYSTem:COMMunicate:BB<HwInstance>:NETWork:IPADdress:MODE {param}')

	def get_value(self) -> str:
		"""SCPI: SYSTem:COMMunicate:BB<HW>:NETWork:IPADdress \n
		Snippet: value: str = driver.system.communicate.bb.network.ipAddress.get_value() \n
		Sets the IP address. \n
			:return: ip_address: string Range: 0.0.0.0. to ff.ff.ff.ff
		"""
		response = self._core.io.query_str('SYSTem:COMMunicate:BB<HwInstance>:NETWork:IPADdress?')
		return trim_str_response(response)

	def set_value(self, ip_address: str) -> None:
		"""SCPI: SYSTem:COMMunicate:BB<HW>:NETWork:IPADdress \n
		Snippet: driver.system.communicate.bb.network.ipAddress.set_value(ip_address = '1') \n
		Sets the IP address. \n
			:param ip_address: string Range: 0.0.0.0. to ff.ff.ff.ff
		"""
		param = Conversions.value_to_quoted_str(ip_address)
		self._core.io.write(f'SYSTem:COMMunicate:BB<HwInstance>:NETWork:IPADdress {param}')

	def clone(self) -> 'IpAddress':
		"""Clones the group by creating new object from it and its whole existing sub-groups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = IpAddress(self._core, self._base.parent)
		self._base.synchronize_repcaps(new_group)
		return new_group



from ..........Internal.Core import Core
from ..........Internal.CommandsGroup import CommandsGroup
from ..........Internal import Conversions
from .......... import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Phase:
	"""Phase commands group definition. 1 total commands, 0 Sub-groups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._base = CommandsGroup("phase", core, parent)

	def set(self, phase: float, mimoTap=repcap.MimoTap.Default) -> None:
		"""SCPI: [SOURce<HW>]:FSIMulator:MIMO:TAP<CH>:KRONecker:CORRelation:TX:DH:PHASe \n
		Snippet: driver.source.fsimulator.mimo.tap.kronecker.correlation.tx.dh.phase.set(phase = 1.0, mimoTap = repcap.MimoTap.Default) \n
		No command help available \n
			:param phase: No help available
			:param mimoTap: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Tap')"""
		param = Conversions.decimal_value_to_str(phase)
		mimoTap_cmd_val = self._base.get_repcap_cmd_value(mimoTap, repcap.MimoTap)
		self._core.io.write(f'SOURce<HwInstance>:FSIMulator:MIMO:TAP{mimoTap_cmd_val}:KRONecker:CORRelation:TX:DH:PHASe {param}')

	def get(self, mimoTap=repcap.MimoTap.Default) -> float:
		"""SCPI: [SOURce<HW>]:FSIMulator:MIMO:TAP<CH>:KRONecker:CORRelation:TX:DH:PHASe \n
		Snippet: value: float = driver.source.fsimulator.mimo.tap.kronecker.correlation.tx.dh.phase.get(mimoTap = repcap.MimoTap.Default) \n
		No command help available \n
			:param mimoTap: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Tap')
			:return: phase: No help available"""
		mimoTap_cmd_val = self._base.get_repcap_cmd_value(mimoTap, repcap.MimoTap)
		response = self._core.io.query_str(f'SOURce<HwInstance>:FSIMulator:MIMO:TAP{mimoTap_cmd_val}:KRONecker:CORRelation:TX:DH:PHASe?')
		return Conversions.str_to_float(response)



from .........Internal.Core import Core
from .........Internal.CommandsGroup import CommandsGroup
from .........Internal import Conversions
from ......... import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Preamble:
	"""Preamble commands group definition. 1 total commands, 0 Sub-groups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._base = CommandsGroup("preamble", core, parent)

	def get(self, mobileStation=repcap.MobileStation.Default) -> float:
		"""SCPI: [SOURce<HW>]:BB:W3GPp:MSTation<ST>:PCPCh:TIMing:DPOWer:PREamble \n
		Snippet: value: float = driver.source.bb.w3Gpp.mstation.pcpch.timing.dpower.preamble.get(mobileStation = repcap.MobileStation.Default) \n
		Queries level correction value for the last AICH preamble before the message part. This value is identical to the
		correction value for the CD preamble. The level of the other preambles can be calculated by subtracting the set Preamble
		Power Step. \n
			:param mobileStation: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Mstation')
			:return: preamble: float Range: -80 to 0"""
		mobileStation_cmd_val = self._base.get_repcap_cmd_value(mobileStation, repcap.MobileStation)
		response = self._core.io.query_str(f'SOURce<HwInstance>:BB:W3GPp:MSTation{mobileStation_cmd_val}:PCPCh:TIMing:DPOWer:PREamble?')
		return Conversions.str_to_float(response)



from ...Internal.Core import Core
from ...Internal.CommandsGroup import CommandsGroup
from ...Internal import Conversions
from ... import enums


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Identification:
	"""Identification commands group definition. 2 total commands, 0 Sub-groups, 2 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._base = CommandsGroup("identification", core, parent)

	def preset(self) -> None:
		"""SCPI: SYSTem:IDENtification:PRESet \n
		Snippet: driver.system.identification.preset() \n
		Sets the *IDN and *OPT strings in user defined mode to default values. \n
		"""
		self._core.io.write(f'SYSTem:IDENtification:PRESet')

	def preset_with_opc(self) -> None:
		"""SCPI: SYSTem:IDENtification:PRESet \n
		Snippet: driver.system.identification.preset_with_opc() \n
		Sets the *IDN and *OPT strings in user defined mode to default values. \n
		Same as preset, but waits for the operation to complete before continuing further. Use the RsSmw.utilities.opc_timeout_set() to set the timeout value. \n
		"""
		self._core.io.write_with_opc(f'SYSTem:IDENtification:PRESet')

	# noinspection PyTypeChecker
	def get_value(self) -> enums.AutoUser:
		"""SCPI: SYSTem:IDENtification \n
		Snippet: value: enums.AutoUser = driver.system.identification.get_value() \n
		Selects the mode to determine the 'IDN String' and the 'OPT String' for the instrument, selected with command method
		RsSmw.System.language. Note: While working in an emulation mode, the R&S SMW specific command set is disabled, that is,
		the SCPI command method RsSmw.System.Identification.value is discarded. \n
			:return: identification: AUTO| USER AUTO Automatically determines the strings. USER User-defined strings can be selected.
		"""
		response = self._core.io.query_str('SYSTem:IDENtification?')
		return Conversions.str_to_scalar_enum(response, enums.AutoUser)

	def set_value(self, identification: enums.AutoUser) -> None:
		"""SCPI: SYSTem:IDENtification \n
		Snippet: driver.system.identification.set_value(identification = enums.AutoUser.AUTO) \n
		Selects the mode to determine the 'IDN String' and the 'OPT String' for the instrument, selected with command method
		RsSmw.System.language. Note: While working in an emulation mode, the R&S SMW specific command set is disabled, that is,
		the SCPI command method RsSmw.System.Identification.value is discarded. \n
			:param identification: AUTO| USER AUTO Automatically determines the strings. USER User-defined strings can be selected.
		"""
		param = Conversions.enum_scalar_to_str(identification, enums.AutoUser)
		self._core.io.write(f'SYSTem:IDENtification {param}')



from .....Internal.Core import Core
from .....Internal.CommandsGroup import CommandsGroup
from .....Internal import Conversions
from ..... import enums


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Powc:
	"""Powc commands group definition. 4 total commands, 0 Sub-groups, 4 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._base = CommandsGroup("powc", core, parent)

	# noinspection PyTypeChecker
	def get_lev_reference(self) -> enums.EutraPowcLevRef:
		"""SCPI: [SOURce<HW>]:BB:EUTRa:POWC:LEVReference \n
		Snippet: value: enums.EutraPowcLevRef = driver.source.bb.eutra.powc.get_lev_reference() \n
		Defines the reference for the 'Level' display in the status bar. \n
			:return: level_reference: FRMS| DRMS| UEBurst | URMS | NPBCH FRMS The displayed RMS and PEP are measured during the whole frame. All frames are considered, not only the first one. DRMS The displayed RMS and PEP are measured during the DL part of the frame (all DL subframes and the DwPTS) . All frames are considered, not only the first one. URMS The displayed RMS and PEP are measured during the UL part of the frame (all UL subframes and the UpPTS) . All frames are considered, not only the first one. UEBurst The displayed RMS and PEP are measured during a single subframe (or slot) of a certain UE. NPBCH In NB-IoT standalone operation, the displayed RMS and PEP are measured during the NPBCH symbols 3, 9 and 11.
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:BB:EUTRa:POWC:LEVReference?')
		return Conversions.str_to_scalar_enum(response, enums.EutraPowcLevRef)

	def set_lev_reference(self, level_reference: enums.EutraPowcLevRef) -> None:
		"""SCPI: [SOURce<HW>]:BB:EUTRa:POWC:LEVReference \n
		Snippet: driver.source.bb.eutra.powc.set_lev_reference(level_reference = enums.EutraPowcLevRef.DRMS) \n
		Defines the reference for the 'Level' display in the status bar. \n
			:param level_reference: FRMS| DRMS| UEBurst | URMS | NPBCH FRMS The displayed RMS and PEP are measured during the whole frame. All frames are considered, not only the first one. DRMS The displayed RMS and PEP are measured during the DL part of the frame (all DL subframes and the DwPTS) . All frames are considered, not only the first one. URMS The displayed RMS and PEP are measured during the UL part of the frame (all UL subframes and the UpPTS) . All frames are considered, not only the first one. UEBurst The displayed RMS and PEP are measured during a single subframe (or slot) of a certain UE. NPBCH In NB-IoT standalone operation, the displayed RMS and PEP are measured during the NPBCH symbols 3, 9 and 11.
		"""
		param = Conversions.enum_scalar_to_str(level_reference, enums.EutraPowcLevRef)
		self._core.io.write(f'SOURce<HwInstance>:BB:EUTRa:POWC:LEVReference {param}')

	# noinspection PyTypeChecker
	def get_ref_channel(self) -> enums.EutraPowcRefChan:
		"""SCPI: [SOURce<HW>]:BB:EUTRa:POWC:REFChannel \n
		Snippet: value: enums.EutraPowcRefChan = driver.source.bb.eutra.powc.get_ref_channel() \n
		If [:SOURce<hw>]:BB:EUTRa:POWC:LEVReferenceUEBurst, queries the channel type to that the measured RMS and PEP are
		referring. \n
			:return: ref_channel: NF| PUSCH| PUCCH| PRACH| SRS| PUCPUS | SL
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:BB:EUTRa:POWC:REFChannel?')
		return Conversions.str_to_scalar_enum(response, enums.EutraPowcRefChan)

	def set_ref_channel(self, ref_channel: enums.EutraPowcRefChan) -> None:
		"""SCPI: [SOURce<HW>]:BB:EUTRa:POWC:REFChannel \n
		Snippet: driver.source.bb.eutra.powc.set_ref_channel(ref_channel = enums.EutraPowcRefChan.NF) \n
		If [:SOURce<hw>]:BB:EUTRa:POWC:LEVReferenceUEBurst, queries the channel type to that the measured RMS and PEP are
		referring. \n
			:param ref_channel: NF| PUSCH| PUCCH| PRACH| SRS| PUCPUS | SL
		"""
		param = Conversions.enum_scalar_to_str(ref_channel, enums.EutraPowcRefChan)
		self._core.io.write(f'SOURce<HwInstance>:BB:EUTRa:POWC:REFChannel {param}')

	def get_ref_subframe(self) -> int:
		"""SCPI: [SOURce<HW>]:BB:EUTRa:POWC:REFSubframe \n
		Snippet: value: int = driver.source.bb.eutra.powc.get_ref_subframe() \n
		If [:SOURce<hw>]:BB:EUTRa:POWC:LEVReferenceUEBurst, queries the subframe or slot number used as reference for measuring
		the RMS and PEP values. \n
			:return: ref_subframe: integer Range: 0 to 39
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:BB:EUTRa:POWC:REFSubframe?')
		return Conversions.str_to_int(response)

	# noinspection PyTypeChecker
	def get_rue(self) -> enums.MobStatType:
		"""SCPI: [SOURce<HW>]:BB:EUTRa:POWC:RUE \n
		Snippet: value: enums.MobStatType = driver.source.bb.eutra.powc.get_rue() \n
		If [:SOURce<hw>]:BB:EUTRa:POWC:LEVReferenceUEBurst, queries the UE to that the measured RMS and PEP are referring. \n
			:return: reference_ue: UE1| UE2| UE3| UE4
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:BB:EUTRa:POWC:RUE?')
		return Conversions.str_to_scalar_enum(response, enums.MobStatType)



from ......Internal.Core import Core
from ......Internal.CommandsGroup import CommandsGroup
from ......Internal import Conversions


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Blank:
	"""Blank commands group definition. 2 total commands, 0 Sub-groups, 2 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._base = CommandsGroup("blank", core, parent)

	def get_time(self) -> float:
		"""SCPI: [SOURce<HW>]:BB:PRAMp:RAMP:BLANk:TIME \n
		Snippet: value: float = driver.source.bb.pramp.ramp.blank.get_time() \n
		Sets the RF blanking time. To activate RF blanking, use command[:SOURce<hw>]:BB:PRAMp:RAMP:BLANk[:STATe]. \n
			:return: rf_blanking: float Range: 5E-9 to 1E-3, Unit: s
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:BB:PRAMp:RAMP:BLANk:TIME?')
		return Conversions.str_to_float(response)

	def set_time(self, rf_blanking: float) -> None:
		"""SCPI: [SOURce<HW>]:BB:PRAMp:RAMP:BLANk:TIME \n
		Snippet: driver.source.bb.pramp.ramp.blank.set_time(rf_blanking = 1.0) \n
		Sets the RF blanking time. To activate RF blanking, use command[:SOURce<hw>]:BB:PRAMp:RAMP:BLANk[:STATe]. \n
			:param rf_blanking: float Range: 5E-9 to 1E-3, Unit: s
		"""
		param = Conversions.decimal_value_to_str(rf_blanking)
		self._core.io.write(f'SOURce<HwInstance>:BB:PRAMp:RAMP:BLANk:TIME {param}')

	def get_state(self) -> bool:
		"""SCPI: [SOURce<HW>]:BB:PRAMp:RAMP:BLANk:[STATe] \n
		Snippet: value: bool = driver.source.bb.pramp.ramp.blank.get_state() \n
		Activates the RF blanking. To determine the blanking interval, use command [:SOURce<hw>]:BB:PRAMp:RAMP:BLANk[:STATe]. \n
			:return: enable_rf_blank: 0| 1| OFF| ON
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:BB:PRAMp:RAMP:BLANk:STATe?')
		return Conversions.str_to_bool(response)

	def set_state(self, enable_rf_blank: bool) -> None:
		"""SCPI: [SOURce<HW>]:BB:PRAMp:RAMP:BLANk:[STATe] \n
		Snippet: driver.source.bb.pramp.ramp.blank.set_state(enable_rf_blank = False) \n
		Activates the RF blanking. To determine the blanking interval, use command [:SOURce<hw>]:BB:PRAMp:RAMP:BLANk[:STATe]. \n
			:param enable_rf_blank: 0| 1| OFF| ON
		"""
		param = Conversions.bool_to_str(enable_rf_blank)
		self._core.io.write(f'SOURce<HwInstance>:BB:PRAMp:RAMP:BLANk:STATe {param}')



from ........Internal.Core import Core
from ........Internal.CommandsGroup import CommandsGroup
from ........Internal.RepeatedCapability import RepeatedCapability
from ........ import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Cell:
	"""Cell commands group definition. 16 total commands, 9 Sub-groups, 0 group commands
	Repeated Capability: CellNull, default value after init: CellNull.Nr0"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._base = CommandsGroup("cell", core, parent)
		self._base.rep_cap = RepeatedCapability(self._base.group_name, 'repcap_cellNull_get', 'repcap_cellNull_set', repcap.CellNull.Nr0)

	def repcap_cellNull_set(self, enum_value: repcap.CellNull) -> None:
		"""Repeated Capability default value numeric suffix.
		This value is used, if you do not explicitely set it in the child set/get methods, or if you leave it to CellNull.Default
		Default value after init: CellNull.Nr0"""
		self._base.set_repcap_enum_value(enum_value)

	def repcap_cellNull_get(self) -> repcap.CellNull:
		"""Returns the current default repeated capability for the child set/get methods"""
		# noinspection PyTypeChecker
		return self._base.get_repcap_enum_value()

	@property
	def cdState(self):
		"""cdState commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_cdState'):
			from .CdState import CdState
			self._cdState = CdState(self._core, self._base)
		return self._cdState

	@property
	def csirs(self):
		"""csirs commands group. 8 Sub-classes, 0 commands."""
		if not hasattr(self, '_csirs'):
			from .Csirs import Csirs
			self._csirs = Csirs(self._core, self._base)
		return self._csirs

	@property
	def duration(self):
		"""duration commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_duration'):
			from .Duration import Duration
			self._duration = Duration(self._core, self._base)
		return self._duration

	@property
	def nzpNum(self):
		"""nzpNum commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_nzpNum'):
			from .NzpNum import NzpNum
			self._nzpNum = NzpNum(self._core, self._base)
		return self._nzpNum

	@property
	def offset(self):
		"""offset commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_offset'):
			from .Offset import Offset
			self._offset = Offset(self._core, self._base)
		return self._offset

	@property
	def pattern(self):
		"""pattern commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_pattern'):
			from .Pattern import Pattern
			self._pattern = Pattern(self._core, self._base)
		return self._pattern

	@property
	def periodicity(self):
		"""periodicity commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_periodicity'):
			from .Periodicity import Periodicity
			self._periodicity = Periodicity(self._core, self._base)
		return self._periodicity

	@property
	def state(self):
		"""state commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_state'):
			from .State import State
			self._state = State(self._core, self._base)
		return self._state

	@property
	def zpNum(self):
		"""zpNum commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_zpNum'):
			from .ZpNum import ZpNum
			self._zpNum = ZpNum(self._core, self._base)
		return self._zpNum

	def clone(self) -> 'Cell':
		"""Clones the group by creating new object from it and its whole existing sub-groups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = Cell(self._core, self._base.parent)
		self._base.synchronize_repcaps(new_group)
		return new_group



from .......Internal.Core import Core
from .......Internal.CommandsGroup import CommandsGroup
from .......Internal import Conversions
from ....... import enums
from ....... import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Ftype:
	"""Ftype commands group definition. 1 total commands, 0 Sub-groups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._base = CommandsGroup("ftype", core, parent)

	def set(self, frame_type: enums.NfcApgEnericFrameType, commandBlock=repcap.CommandBlock.Default) -> None:
		"""SCPI: [SOURce<HW>]:BB:NFC:CBLock<CH>:APGeneric:FTYPe \n
		Snippet: driver.source.bb.nfc.cblock.apGeneric.ftype.set(frame_type = enums.NfcApgEnericFrameType.BOSDd, commandBlock = repcap.CommandBlock.Default) \n
		Selects a frame type for 'Command Type > GENERIC'. \n
			:param frame_type: SHORt| STANdard| BOSDd
			:param commandBlock: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Cblock')"""
		param = Conversions.enum_scalar_to_str(frame_type, enums.NfcApgEnericFrameType)
		commandBlock_cmd_val = self._base.get_repcap_cmd_value(commandBlock, repcap.CommandBlock)
		self._core.io.write(f'SOURce<HwInstance>:BB:NFC:CBLock{commandBlock_cmd_val}:APGeneric:FTYPe {param}')

	# noinspection PyTypeChecker
	def get(self, commandBlock=repcap.CommandBlock.Default) -> enums.NfcApgEnericFrameType:
		"""SCPI: [SOURce<HW>]:BB:NFC:CBLock<CH>:APGeneric:FTYPe \n
		Snippet: value: enums.NfcApgEnericFrameType = driver.source.bb.nfc.cblock.apGeneric.ftype.get(commandBlock = repcap.CommandBlock.Default) \n
		Selects a frame type for 'Command Type > GENERIC'. \n
			:param commandBlock: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Cblock')
			:return: frame_type: SHORt| STANdard| BOSDd"""
		commandBlock_cmd_val = self._base.get_repcap_cmd_value(commandBlock, repcap.CommandBlock)
		response = self._core.io.query_str(f'SOURce<HwInstance>:BB:NFC:CBLock{commandBlock_cmd_val}:APGeneric:FTYPe?')
		return Conversions.str_to_scalar_enum(response, enums.NfcApgEnericFrameType)



from ........Internal.Core import Core
from ........Internal.CommandsGroup import CommandsGroup
from ........Internal.RepeatedCapability import RepeatedCapability
from ........ import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Pmch:
	"""Pmch commands group definition. 10 total commands, 10 Sub-groups, 0 group commands
	Repeated Capability: IndexNull, default value after init: IndexNull.Nr0"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._base = CommandsGroup("pmch", core, parent)
		self._base.rep_cap = RepeatedCapability(self._base.group_name, 'repcap_indexNull_get', 'repcap_indexNull_set', repcap.IndexNull.Nr0)

	def repcap_indexNull_set(self, enum_value: repcap.IndexNull) -> None:
		"""Repeated Capability default value numeric suffix.
		This value is used, if you do not explicitely set it in the child set/get methods, or if you leave it to IndexNull.Default
		Default value after init: IndexNull.Nr0"""
		self._base.set_repcap_enum_value(enum_value)

	def repcap_indexNull_get(self) -> repcap.IndexNull:
		"""Returns the current default repeated capability for the child set/get methods"""
		# noinspection PyTypeChecker
		return self._base.get_repcap_enum_value()

	@property
	def data(self):
		"""data commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_data'):
			from .Data import Data
			self._data = Data(self._core, self._base)
		return self._data

	@property
	def dlist(self):
		"""dlist commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_dlist'):
			from .Dlist import Dlist
			self._dlist = Dlist(self._core, self._base)
		return self._dlist

	@property
	def mcs(self):
		"""mcs commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_mcs'):
			from .Mcs import Mcs
			self._mcs = Mcs(self._core, self._base)
		return self._mcs

	@property
	def mcsTwo(self):
		"""mcsTwo commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_mcsTwo'):
			from .McsTwo import McsTwo
			self._mcsTwo = McsTwo(self._core, self._base)
		return self._mcsTwo

	@property
	def mod(self):
		"""mod commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_mod'):
			from .Mod import Mod
			self._mod = Mod(self._core, self._base)
		return self._mod

	@property
	def pattern(self):
		"""pattern commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_pattern'):
			from .Pattern import Pattern
			self._pattern = Pattern(self._core, self._base)
		return self._pattern

	@property
	def saEnd(self):
		"""saEnd commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_saEnd'):
			from .SaEnd import SaEnd
			self._saEnd = SaEnd(self._core, self._base)
		return self._saEnd

	@property
	def saStart(self):
		"""saStart commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_saStart'):
			from .SaStart import SaStart
			self._saStart = SaStart(self._core, self._base)
		return self._saStart

	@property
	def speriod(self):
		"""speriod commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_speriod'):
			from .Speriod import Speriod
			self._speriod = Speriod(self._core, self._base)
		return self._speriod

	@property
	def state(self):
		"""state commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_state'):
			from .State import State
			self._state = State(self._core, self._base)
		return self._state

	def clone(self) -> 'Pmch':
		"""Clones the group by creating new object from it and its whole existing sub-groups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = Pmch(self._core, self._base.parent)
		self._base.synchronize_repcaps(new_group)
		return new_group



from .....Internal.Core import Core
from .....Internal.CommandsGroup import CommandsGroup
from .....Internal import Conversions


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Step:
	"""Step commands group definition. 1 total commands, 0 Sub-groups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._base = CommandsGroup("step", core, parent)

	def get_logarithmic(self) -> float:
		"""SCPI: [SOURce<HW>]:SWEep:POWer:STEP:[LOGarithmic] \n
		Snippet: value: float = driver.source.sweep.power.step.get_logarithmic() \n
		Sets a logarithmically determined step size for the RF level sweep. The level is increased by a logarithmically
		calculated fraction of the current level. See 'Correlating Parameters in Sweep Mode'. \n
			:return: logarithmic: float The unit dB is mandatory. Range: 0.01 to 139 dB, Unit: dB
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:SWEep:POWer:STEP:LOGarithmic?')
		return Conversions.str_to_float(response)

	def set_logarithmic(self, logarithmic: float) -> None:
		"""SCPI: [SOURce<HW>]:SWEep:POWer:STEP:[LOGarithmic] \n
		Snippet: driver.source.sweep.power.step.set_logarithmic(logarithmic = 1.0) \n
		Sets a logarithmically determined step size for the RF level sweep. The level is increased by a logarithmically
		calculated fraction of the current level. See 'Correlating Parameters in Sweep Mode'. \n
			:param logarithmic: float The unit dB is mandatory. Range: 0.01 to 139 dB, Unit: dB
		"""
		param = Conversions.decimal_value_to_str(logarithmic)
		self._core.io.write(f'SOURce<HwInstance>:SWEep:POWer:STEP:LOGarithmic {param}')



from ..........Internal.Core import Core
from ..........Internal.CommandsGroup import CommandsGroup
from ..........Internal.RepeatedCapability import RepeatedCapability
from .......... import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Row:
	"""Row commands group definition. 4 total commands, 1 Sub-groups, 0 group commands
	Repeated Capability: Row, default value after init: Row.Nr1"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._base = CommandsGroup("row", core, parent)
		self._base.rep_cap = RepeatedCapability(self._base.group_name, 'repcap_row_get', 'repcap_row_set', repcap.Row.Nr1)

	def repcap_row_set(self, enum_value: repcap.Row) -> None:
		"""Repeated Capability default value numeric suffix.
		This value is used, if you do not explicitely set it in the child set/get methods, or if you leave it to Row.Default
		Default value after init: Row.Nr1"""
		self._base.set_repcap_enum_value(enum_value)

	def repcap_row_get(self) -> repcap.Row:
		"""Returns the current default repeated capability for the child set/get methods"""
		# noinspection PyTypeChecker
		return self._base.get_repcap_enum_value()

	@property
	def column(self):
		"""column commands group. 4 Sub-classes, 0 commands."""
		if not hasattr(self, '_column'):
			from .Column import Column
			self._column = Column(self._core, self._base)
		return self._column

	def clone(self) -> 'Row':
		"""Clones the group by creating new object from it and its whole existing sub-groups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = Row(self._core, self._base.parent)
		self._base.synchronize_repcaps(new_group)
		return new_group



from ......Internal.Core import Core
from ......Internal.CommandsGroup import CommandsGroup
from ......Internal import Conversions
from ...... import enums


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Smodulation:
	"""Smodulation commands group definition. 7 total commands, 4 Sub-groups, 2 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._base = CommandsGroup("smodulation", core, parent)

	@property
	def clock(self):
		"""clock commands group. 1 Sub-classes, 0 commands."""
		if not hasattr(self, '_clock'):
			from .Clock import Clock
			self._clock = Clock(self._core, self._base)
		return self._clock

	@property
	def ddelay(self):
		"""ddelay commands group. 0 Sub-classes, 2 commands."""
		if not hasattr(self, '_ddelay'):
			from .Ddelay import Ddelay
			self._ddelay = Ddelay(self._core, self._base)
		return self._ddelay

	@property
	def rcvState(self):
		"""rcvState commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_rcvState'):
			from .RcvState import RcvState
			self._rcvState = RcvState(self._core, self._base)
		return self._rcvState

	@property
	def throughput(self):
		"""throughput commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_throughput'):
			from .Throughput import Throughput
			self._throughput = Throughput(self._core, self._base)
		return self._throughput

	# noinspection PyTypeChecker
	def get_border(self) -> enums.BitOrder:
		"""SCPI: [SOURce<HW>]:BB:DM:SMODulation:BORDer \n
		Snippet: value: enums.BitOrder = driver.source.bb.dm.smodulation.get_border() \n
		Sets the bit order for processing extern serial data. \n
			:return: bit_order: LSBit| MSBit
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:BB:DM:SMODulation:BORDer?')
		return Conversions.str_to_scalar_enum(response, enums.BitOrder)

	def set_border(self, bit_order: enums.BitOrder) -> None:
		"""SCPI: [SOURce<HW>]:BB:DM:SMODulation:BORDer \n
		Snippet: driver.source.bb.dm.smodulation.set_border(bit_order = enums.BitOrder.LSBit) \n
		Sets the bit order for processing extern serial data. \n
			:param bit_order: LSBit| MSBit
		"""
		param = Conversions.enum_scalar_to_str(bit_order, enums.BitOrder)
		self._core.io.write(f'SOURce<HwInstance>:BB:DM:SMODulation:BORDer {param}')

	def get_cdt_deviation(self) -> float:
		"""SCPI: [SOURce<HW>]:BB:DM:SMODulation:CDTDeviation \n
		Snippet: value: float = driver.source.bb.dm.smodulation.get_cdt_deviation() \n
		Queries the timing deviations (time offset) between the clock and the data signals. \n
			:return: deviation: float Range: -5E-3 to 5E-3
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:BB:DM:SMODulation:CDTDeviation?')
		return Conversions.str_to_float(response)

	def clone(self) -> 'Smodulation':
		"""Clones the group by creating new object from it and its whole existing sub-groups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = Smodulation(self._core, self._base.parent)
		self._base.synchronize_repcaps(new_group)
		return new_group



from ......Internal.Core import Core
from ......Internal.CommandsGroup import CommandsGroup
from ......Internal import Conversions


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Los:
	"""Los commands group definition. 12 total commands, 3 Sub-groups, 3 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._base = CommandsGroup("los", core, parent)

	@property
	def arrival(self):
		"""arrival commands group. 1 Sub-classes, 1 commands."""
		if not hasattr(self, '_arrival'):
			from .Arrival import Arrival
			self._arrival = Arrival(self._core, self._base)
		return self._arrival

	@property
	def departure(self):
		"""departure commands group. 1 Sub-classes, 1 commands."""
		if not hasattr(self, '_departure'):
			from .Departure import Departure
			self._departure = Departure(self._core, self._base)
		return self._departure

	@property
	def random(self):
		"""random commands group. 1 Sub-classes, 0 commands."""
		if not hasattr(self, '_random'):
			from .Random import Random
			self._random = Random(self._core, self._base)
		return self._random

	def get_distance(self) -> float:
		"""SCPI: [SOURce<HW>]:FSIMulator:SCM:LOS:DISTance \n
		Snippet: value: float = driver.source.fsimulator.scm.los.get_distance() \n
		Sets the distance between the base station (BS) and the user terminal (UT) . \n
			:return: los_3_ddistance: float Range: 0 to 1000
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:FSIMulator:SCM:LOS:DISTance?')
		return Conversions.str_to_float(response)

	def set_distance(self, los_3_ddistance: float) -> None:
		"""SCPI: [SOURce<HW>]:FSIMulator:SCM:LOS:DISTance \n
		Snippet: driver.source.fsimulator.scm.los.set_distance(los_3_ddistance = 1.0) \n
		Sets the distance between the base station (BS) and the user terminal (UT) . \n
			:param los_3_ddistance: float Range: 0 to 1000
		"""
		param = Conversions.decimal_value_to_str(los_3_ddistance)
		self._core.io.write(f'SOURce<HwInstance>:FSIMulator:SCM:LOS:DISTance {param}')

	def get_kfactor(self) -> float:
		"""SCPI: [SOURce<HW>]:FSIMulator:SCM:LOS:KFACtor \n
		Snippet: value: float = driver.source.fsimulator.scm.los.get_kfactor() \n
		Sets the ricean K factor. \n
			:return: factor: float Range: -50 to 0
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:FSIMulator:SCM:LOS:KFACtor?')
		return Conversions.str_to_float(response)

	def set_kfactor(self, factor: float) -> None:
		"""SCPI: [SOURce<HW>]:FSIMulator:SCM:LOS:KFACtor \n
		Snippet: driver.source.fsimulator.scm.los.set_kfactor(factor = 1.0) \n
		Sets the ricean K factor. \n
			:param factor: float Range: -50 to 0
		"""
		param = Conversions.decimal_value_to_str(factor)
		self._core.io.write(f'SOURce<HwInstance>:FSIMulator:SCM:LOS:KFACtor {param}')

	def get_state(self) -> bool:
		"""SCPI: [SOURce<HW>]:FSIMulator:SCM:LOS:STATe \n
		Snippet: value: bool = driver.source.fsimulator.scm.los.get_state() \n
		Adds a line-of-sight (LOS) component to the cluster. \n
			:return: state: 0| 1| OFF| ON
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:FSIMulator:SCM:LOS:STATe?')
		return Conversions.str_to_bool(response)

	def set_state(self, state: bool) -> None:
		"""SCPI: [SOURce<HW>]:FSIMulator:SCM:LOS:STATe \n
		Snippet: driver.source.fsimulator.scm.los.set_state(state = False) \n
		Adds a line-of-sight (LOS) component to the cluster. \n
			:param state: 0| 1| OFF| ON
		"""
		param = Conversions.bool_to_str(state)
		self._core.io.write(f'SOURce<HwInstance>:FSIMulator:SCM:LOS:STATe {param}')

	def clone(self) -> 'Los':
		"""Clones the group by creating new object from it and its whole existing sub-groups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = Los(self._core, self._base.parent)
		self._base.synchronize_repcaps(new_group)
		return new_group



from .....Internal.Core import Core
from .....Internal.CommandsGroup import CommandsGroup
from .....Internal import Conversions


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Tdd:
	"""Tdd commands group definition. 2 total commands, 0 Sub-groups, 2 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._base = CommandsGroup("tdd", core, parent)

	def get_sps_conf(self) -> int:
		"""SCPI: [SOURce<HW>]:BB:V5G:TDD:SPSConf \n
		Snippet: value: int = driver.source.bb.v5G.tdd.get_sps_conf() \n
		No command help available \n
			:return: spec_subfr_conf: No help available
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:BB:V5G:TDD:SPSConf?')
		return Conversions.str_to_int(response)

	def set_sps_conf(self, spec_subfr_conf: int) -> None:
		"""SCPI: [SOURce<HW>]:BB:V5G:TDD:SPSConf \n
		Snippet: driver.source.bb.v5G.tdd.set_sps_conf(spec_subfr_conf = 1) \n
		No command help available \n
			:param spec_subfr_conf: No help available
		"""
		param = Conversions.decimal_value_to_str(spec_subfr_conf)
		self._core.io.write(f'SOURce<HwInstance>:BB:V5G:TDD:SPSConf {param}')

	def get_ud_conf(self) -> int:
		"""SCPI: [SOURce<HW>]:BB:V5G:TDD:UDConf \n
		Snippet: value: int = driver.source.bb.v5G.tdd.get_ud_conf() \n
		No command help available \n
			:return: ul_dl_conf: No help available
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:BB:V5G:TDD:UDConf?')
		return Conversions.str_to_int(response)

	def set_ud_conf(self, ul_dl_conf: int) -> None:
		"""SCPI: [SOURce<HW>]:BB:V5G:TDD:UDConf \n
		Snippet: driver.source.bb.v5G.tdd.set_ud_conf(ul_dl_conf = 1) \n
		No command help available \n
			:param ul_dl_conf: No help available
		"""
		param = Conversions.decimal_value_to_str(ul_dl_conf)
		self._core.io.write(f'SOURce<HwInstance>:BB:V5G:TDD:UDConf {param}')



from ....Internal.Core import Core
from ....Internal.CommandsGroup import CommandsGroup
from ....Internal import Conversions
from .... import enums


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Step:
	"""Step commands group definition. 2 total commands, 0 Sub-groups, 2 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._base = CommandsGroup("step", core, parent)

	# noinspection PyTypeChecker
	def get_mode(self) -> enums.FreqStepMode:
		"""SCPI: [SOURce<HW>]:POWer:STEP:MODE \n
		Snippet: value: enums.FreqStepMode = driver.source.power.step.get_mode() \n
		Defines the type of step width to vary the RF output power step-by-step with the commands POW UP or POW DOWN. You can
		define the step mode for each path separately. \n
			:return: mode: DECimal| USER DECimal Increases or decreases the level in steps of ten. USER Increases or decreases the level in increments, determined with the command method RsSmw.Source.Power.Level.Immediate.amplitude.
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:POWer:STEP:MODE?')
		return Conversions.str_to_scalar_enum(response, enums.FreqStepMode)

	def set_mode(self, mode: enums.FreqStepMode) -> None:
		"""SCPI: [SOURce<HW>]:POWer:STEP:MODE \n
		Snippet: driver.source.power.step.set_mode(mode = enums.FreqStepMode.DECimal) \n
		Defines the type of step width to vary the RF output power step-by-step with the commands POW UP or POW DOWN. You can
		define the step mode for each path separately. \n
			:param mode: DECimal| USER DECimal Increases or decreases the level in steps of ten. USER Increases or decreases the level in increments, determined with the command method RsSmw.Source.Power.Level.Immediate.amplitude.
		"""
		param = Conversions.enum_scalar_to_str(mode, enums.FreqStepMode)
		self._core.io.write(f'SOURce<HwInstance>:POWer:STEP:MODE {param}')

	def get_increment(self) -> float:
		"""SCPI: [SOURce<HW>]:POWer:STEP:[INCRement] \n
		Snippet: value: float = driver.source.power.step.get_increment() \n
		Specifies the step width in the appropriate path for POW:STEP:MODE USER. To adjust the level step-by-step with this
		increment value, use the command POW UP, or POW DOWN. Note: The command also sets 'Variation Step' in the manual control,
		that means the user-defined step width for setting the level with the rotary knob or the [Up/Down] arrow keys. \n
			:return: increment: float Range: 0 to 200, Unit: dB
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:POWer:STEP:INCRement?')
		return Conversions.str_to_float(response)

	def set_increment(self, increment: float) -> None:
		"""SCPI: [SOURce<HW>]:POWer:STEP:[INCRement] \n
		Snippet: driver.source.power.step.set_increment(increment = 1.0) \n
		Specifies the step width in the appropriate path for POW:STEP:MODE USER. To adjust the level step-by-step with this
		increment value, use the command POW UP, or POW DOWN. Note: The command also sets 'Variation Step' in the manual control,
		that means the user-defined step width for setting the level with the rotary knob or the [Up/Down] arrow keys. \n
			:param increment: float Range: 0 to 200, Unit: dB
		"""
		param = Conversions.decimal_value_to_str(increment)
		self._core.io.write(f'SOURce<HwInstance>:POWer:STEP:INCRement {param}')



from ..........Internal.Core import Core
from ..........Internal.CommandsGroup import CommandsGroup
from ..........Internal import Conversions
from .......... import enums
from .......... import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Layer:
	"""Layer commands group definition. 1 total commands, 0 Sub-groups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._base = CommandsGroup("layer", core, parent)

	def set(self, layer: enums.EnhBitErr, cell=repcap.Cell.Default) -> None:
		"""SCPI: [SOURce<HW>]:BB:TDSCdma:UP:CELL<ST>:ENH:DCH:BIT:LAYer \n
		Snippet: driver.source.bb.tdscdma.up.cell.enh.dch.bit.layer.set(layer = enums.EnhBitErr.PHYSical, cell = repcap.Cell.Default) \n
		Sets the layer in the coding process at which bit errors are inserted. \n
			:param layer: TRANsport| PHYSical
			:param cell: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Cell')"""
		param = Conversions.enum_scalar_to_str(layer, enums.EnhBitErr)
		cell_cmd_val = self._base.get_repcap_cmd_value(cell, repcap.Cell)
		self._core.io.write(f'SOURce<HwInstance>:BB:TDSCdma:UP:CELL{cell_cmd_val}:ENH:DCH:BIT:LAYer {param}')

	# noinspection PyTypeChecker
	def get(self, cell=repcap.Cell.Default) -> enums.EnhBitErr:
		"""SCPI: [SOURce<HW>]:BB:TDSCdma:UP:CELL<ST>:ENH:DCH:BIT:LAYer \n
		Snippet: value: enums.EnhBitErr = driver.source.bb.tdscdma.up.cell.enh.dch.bit.layer.get(cell = repcap.Cell.Default) \n
		Sets the layer in the coding process at which bit errors are inserted. \n
			:param cell: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Cell')
			:return: layer: TRANsport| PHYSical"""
		cell_cmd_val = self._base.get_repcap_cmd_value(cell, repcap.Cell)
		response = self._core.io.query_str(f'SOURce<HwInstance>:BB:TDSCdma:UP:CELL{cell_cmd_val}:ENH:DCH:BIT:LAYer?')
		return Conversions.str_to_scalar_enum(response, enums.EnhBitErr)



from .......Internal.Core import Core
from .......Internal.CommandsGroup import CommandsGroup
from .......Internal import Conversions


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Awgn:
	"""Awgn commands group definition. 3 total commands, 1 Sub-groups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._base = CommandsGroup("awgn", core, parent)

	@property
	def create(self):
		"""create commands group. 0 Sub-classes, 2 commands."""
		if not hasattr(self, '_create'):
			from .Create import Create
			self._create = Create(self._core, self._base)
		return self._create

	def get_samples(self) -> int:
		"""SCPI: [SOURce<HW>]:BB:ARBitrary:TSIGnal:AWGN:SAMPles \n
		Snippet: value: int = driver.source.bb.arbitrary.tsignal.awgn.get_samples() \n
		Sets the number of samples generated for the AWGN waveform. \n
			:return: par_awgn_samp: integer Range: 1E6 to 1E9
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:BB:ARBitrary:TSIGnal:AWGN:SAMPles?')
		return Conversions.str_to_int(response)

	def set_samples(self, par_awgn_samp: int) -> None:
		"""SCPI: [SOURce<HW>]:BB:ARBitrary:TSIGnal:AWGN:SAMPles \n
		Snippet: driver.source.bb.arbitrary.tsignal.awgn.set_samples(par_awgn_samp = 1) \n
		Sets the number of samples generated for the AWGN waveform. \n
			:param par_awgn_samp: integer Range: 1E6 to 1E9
		"""
		param = Conversions.decimal_value_to_str(par_awgn_samp)
		self._core.io.write(f'SOURce<HwInstance>:BB:ARBitrary:TSIGnal:AWGN:SAMPles {param}')

	def clone(self) -> 'Awgn':
		"""Clones the group by creating new object from it and its whole existing sub-groups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = Awgn(self._core, self._base.parent)
		self._base.synchronize_repcaps(new_group)
		return new_group
